/****************************************************************************
** Meta object code from reading C++ file 'org_freedesktop_DBus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_freedesktop_DBus.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_freedesktop_DBus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6__DBusE_t {};
} // unnamed namespace

template <> constexpr inline auto __DBus::qt_create_metaobjectdata<qt_meta_tag_ZN6__DBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__DBus",
        "NameAcquired",
        "",
        "in0",
        "NameLost",
        "NameOwnerChanged",
        "name",
        "oldOwner",
        "newOwner",
        "FeaturesChanged",
        "value",
        "InterfacesChanged",
        "AddMatch",
        "QDBusPendingReply<>",
        "AddMatchQueued",
        "GetAdtAuditSessionData",
        "QDBusPendingReply<QByteArray>",
        "GetConnectionSELinuxSecurityContext",
        "GetConnectionUnixProcessID",
        "QDBusPendingReply<uint>",
        "GetConnectionUnixUser",
        "GetId",
        "QDBusPendingReply<QString>",
        "GetNameOwner",
        "Hello",
        "ListActivatableNames",
        "QDBusPendingReply<QStringList>",
        "ListNames",
        "ListQueuedOwners",
        "NameHasOwner",
        "QDBusPendingReply<bool>",
        "ReleaseName",
        "ReloadConfig",
        "ReloadConfigQueued",
        "RemoveMatch",
        "RemoveMatchQueued",
        "RequestName",
        "in1",
        "StartServiceByName",
        "UpdateActivationEnvironment",
        "EnvInfoList",
        "UpdateActivationEnvironmentQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Features",
        "Interfaces"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'NameAcquired'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NameLost'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NameOwnerChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'FeaturesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Signal 'InterfacesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Slot 'AddMatch'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'AddMatchQueued'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetAdtAuditSessionData'
        QtMocHelpers::SlotData<QDBusPendingReply<QByteArray>(const QString &)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetConnectionSELinuxSecurityContext'
        QtMocHelpers::SlotData<QDBusPendingReply<QByteArray>(const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetConnectionUnixProcessID'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetConnectionUnixUser'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetId'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'GetNameOwner'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(23, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'Hello'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(24, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'ListActivatableNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(25, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'ListNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(27, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'ListQueuedOwners'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'NameHasOwner'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ReleaseName'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ReloadConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(32, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'ReloadConfigQueued'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RemoveMatch'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(34, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'RemoveMatchQueued'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'RequestName'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &, uint)>(36, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 37 },
        }}),
        // Slot 'StartServiceByName'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &, uint)>(38, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 37 },
        }}),
        // Slot 'UpdateActivationEnvironment'
        QtMocHelpers::SlotData<QDBusPendingReply<>(EnvInfoList)>(39, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 40, 3 },
        }}),
        // Slot 'UpdateActivationEnvironmentQueued'
        QtMocHelpers::SlotData<void(EnvInfoList)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 3 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { 0x80000000 | 44, 45 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 50 }, { 0x80000000 | 51, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Features'
        QtMocHelpers::PropertyData<QStringList>(52, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'Interfaces'
        QtMocHelpers::PropertyData<QStringList>(53, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__DBus, qt_meta_tag_ZN6__DBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __DBus::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6__DBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6__DBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6__DBusE_t>.metaTypes,
    nullptr
} };

void __DBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__DBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->NameAcquired((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->NameLost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->NameOwnerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->FeaturesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->InterfacesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: { QDBusPendingReply<> _r = _t->AddMatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->AddMatchQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: { QDBusPendingReply<QByteArray> _r = _t->GetAdtAuditSessionData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QByteArray> _r = _t->GetConnectionSELinuxSecurityContext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<uint> _r = _t->GetConnectionUnixProcessID((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<uint> _r = _t->GetConnectionUnixUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QString> _r = _t->GetId();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QString> _r = _t->GetNameOwner((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->Hello();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QStringList> _r = _t->ListActivatableNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QStringList> _r = _t->ListNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QStringList> _r = _t->ListQueuedOwners((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<bool> _r = _t->NameHasOwner((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<uint> _r = _t->ReleaseName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->ReloadConfig();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->ReloadConfigQueued(); break;
        case 21: { QDBusPendingReply<> _r = _t->RemoveMatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->RemoveMatchQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: { QDBusPendingReply<uint> _r = _t->RequestName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<uint> _r = _t->StartServiceByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->UpdateActivationEnvironment((*reinterpret_cast<std::add_pointer_t<EnvInfoList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->UpdateActivationEnvironmentQueued((*reinterpret_cast<std::add_pointer_t<EnvInfoList>>(_a[1]))); break;
        case 27: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 28: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 29: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__DBus::*)(const QString & )>(_a, &__DBus::NameAcquired, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__DBus::*)(const QString & )>(_a, &__DBus::NameLost, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__DBus::*)(const QString & , const QString & , const QString & )>(_a, &__DBus::NameOwnerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__DBus::*)(const QStringList & ) const>(_a, &__DBus::FeaturesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__DBus::*)(const QStringList & ) const>(_a, &__DBus::InterfacesChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->features(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->interfaces(); break;
        default: break;
        }
    }
}

const QMetaObject *__DBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__DBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6__DBusE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __DBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void __DBus::NameAcquired(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __DBus::NameLost(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __DBus::NameOwnerChanged(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void __DBus::FeaturesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __DBus *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __DBus::InterfacesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __DBus *>(this), &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
