/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Session1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "session1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Session1Adaptor
 */

Session1Adaptor::Session1Adaptor(Session *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Session1Adaptor::~Session1Adaptor()
{
    // destructor
}

QString Session1Adaptor::GetSessionPath()
{
    // handle method call org.deepin.dde.Session1.GetSessionPath
    return parent()->GetSessionPath();
}

int Session1Adaptor::GetSessionPid()
{
    // handle method call org.deepin.dde.Session1.GetSessionPid
    return parent()->GetSessionPid();
}

void Session1Adaptor::Logout()
{
    // handle method call org.deepin.dde.Session1.Logout
    parent()->Logout();
}


#include "moc_session1adaptor.cpp"
