/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Inhibitor1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef INHIBITOR1ADAPTOR_H
#define INHIBITOR1ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "impl/inhibitor.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.deepin.dde.Inhibitor1
 */
class Inhibitor1Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.deepin.dde.Inhibitor1")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.deepin.dde.Inhibitor1\">\n"
"    <method name=\"GetAppId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"GetClientId\">\n"
"      <arg direction=\"out\" type=\"o\"/>\n"
"    </method>\n"
"    <method name=\"GetFlags\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"    </method>\n"
"    <method name=\"GetReason\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"GetToplevelXid\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Inhibitor1Adaptor(Inhibitor *parent);
    ~Inhibitor1Adaptor() override;

    inline Inhibitor *parent() const
    { return static_cast<Inhibitor *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString GetAppId();
    QDBusObjectPath GetClientId();
    uint GetFlags();
    QString GetReason();
    uint GetToplevelXid();
Q_SIGNALS: // SIGNALS
};

#endif
