/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Login1Manager -p /build/deepin-session/src/dde-session/dbusinterface/org_freedesktop_login1_Manager /build/deepin-session/src/dde-session/dbus/interface/org.freedesktop.login1.Manager.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_FREEDESKTOP_LOGIN1_MANAGER_H
#define ORG_FREEDESKTOP_LOGIN1_MANAGER_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.freedesktop.login1.Manager
 */
class __Login1ManagerPrivate;
class __Login1Manager : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.login1.Manager"; }

public:
    explicit __Login1Manager(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Login1Manager();

    Q_PROPERTY(QString BlockInhibited READ blockInhibited NOTIFY BlockInhibitedChanged)
    QString blockInhibited();

    Q_PROPERTY(QString DelayInhibited READ delayInhibited NOTIFY DelayInhibitedChanged)
    QString delayInhibited();

    Q_PROPERTY(bool Docked READ docked NOTIFY DockedChanged)
    bool docked();

    Q_PROPERTY(bool EnableWallMessages READ enableWallMessages WRITE setEnableWallMessages NOTIFY EnableWallMessagesChanged)
    bool enableWallMessages();
    void setEnableWallMessages(bool value);

    Q_PROPERTY(QString HandleHibernateKey READ handleHibernateKey NOTIFY HandleHibernateKeyChanged)
    QString handleHibernateKey();

    Q_PROPERTY(QString HandleLidSwitch READ handleLidSwitch NOTIFY HandleLidSwitchChanged)
    QString handleLidSwitch();

    Q_PROPERTY(QString HandleLidSwitchDocked READ handleLidSwitchDocked NOTIFY HandleLidSwitchDockedChanged)
    QString handleLidSwitchDocked();

    Q_PROPERTY(QString HandlePowerKey READ handlePowerKey NOTIFY HandlePowerKeyChanged)
    QString handlePowerKey();

    Q_PROPERTY(QString HandleSuspendKey READ handleSuspendKey NOTIFY HandleSuspendKeyChanged)
    QString handleSuspendKey();

    Q_PROPERTY(qulonglong HoldoffTimeoutUSec READ holdoffTimeoutUSec NOTIFY HoldoffTimeoutUSecChanged)
    qulonglong holdoffTimeoutUSec();

    Q_PROPERTY(QString IdleAction READ idleAction NOTIFY IdleActionChanged)
    QString idleAction();

    Q_PROPERTY(qulonglong IdleActionUSec READ idleActionUSec NOTIFY IdleActionUSecChanged)
    qulonglong idleActionUSec();

    Q_PROPERTY(bool IdleHint READ idleHint NOTIFY IdleHintChanged)
    bool idleHint();

    Q_PROPERTY(qulonglong IdleSinceHint READ idleSinceHint NOTIFY IdleSinceHintChanged)
    qulonglong idleSinceHint();

    Q_PROPERTY(qulonglong IdleSinceHintMonotonic READ idleSinceHintMonotonic NOTIFY IdleSinceHintMonotonicChanged)
    qulonglong idleSinceHintMonotonic();

    Q_PROPERTY(qulonglong InhibitDelayMaxUSec READ inhibitDelayMaxUSec NOTIFY InhibitDelayMaxUSecChanged)
    qulonglong inhibitDelayMaxUSec();

    Q_PROPERTY(qulonglong InhibitorsMax READ inhibitorsMax NOTIFY InhibitorsMaxChanged)
    qulonglong inhibitorsMax();

    Q_PROPERTY(QStringList KillExcludeUsers READ killExcludeUsers NOTIFY KillExcludeUsersChanged)
    QStringList killExcludeUsers();

    Q_PROPERTY(QStringList KillOnlyUsers READ killOnlyUsers NOTIFY KillOnlyUsersChanged)
    QStringList killOnlyUsers();

    Q_PROPERTY(bool KillUserProcesses READ killUserProcesses NOTIFY KillUserProcessesChanged)
    bool killUserProcesses();

    Q_PROPERTY(uint NAutoVTs READ nAutoVTs NOTIFY NAutoVTsChanged)
    uint nAutoVTs();

    Q_PROPERTY(qulonglong NCurrentInhibitors READ nCurrentInhibitors NOTIFY NCurrentInhibitorsChanged)
    qulonglong nCurrentInhibitors();

    Q_PROPERTY(qulonglong NCurrentSessions READ nCurrentSessions NOTIFY NCurrentSessionsChanged)
    qulonglong nCurrentSessions();

    Q_PROPERTY(bool PreparingForShutdown READ preparingForShutdown NOTIFY PreparingForShutdownChanged)
    bool preparingForShutdown();

    Q_PROPERTY(bool PreparingForSleep READ preparingForSleep NOTIFY PreparingForSleepChanged)
    bool preparingForSleep();

    Q_PROPERTY(bool RebootToFirmwareSetup READ rebootToFirmwareSetup NOTIFY RebootToFirmwareSetupChanged)
    bool rebootToFirmwareSetup();

    Q_PROPERTY(bool RemoveIPC READ removeIPC NOTIFY RemoveIPCChanged)
    bool removeIPC();

    Q_PROPERTY(qulonglong RuntimeDirectorySize READ runtimeDirectorySize NOTIFY RuntimeDirectorySizeChanged)
    qulonglong runtimeDirectorySize();

    Q_PROPERTY(qulonglong SessionsMax READ sessionsMax NOTIFY SessionsMaxChanged)
    qulonglong sessionsMax();

    Q_PROPERTY(qulonglong UserTasksMax READ userTasksMax NOTIFY UserTasksMaxChanged)
    qulonglong userTasksMax();

    Q_PROPERTY(QString WallMessage READ wallMessage WRITE setWallMessage NOTIFY WallMessageChanged)
    QString wallMessage();
    void setWallMessage(const QString &value);

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> ActivateSession(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("ActivateSession"), argumentList);
    }

    inline void ActivateSessionQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("ActivateSession"), argumentList);
    }


    inline QDBusPendingReply<> ActivateSessionOnSeat(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ActivateSessionOnSeat"), argumentList);
    }

    inline void ActivateSessionOnSeatQueued(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("ActivateSessionOnSeat"), argumentList);
    }


    inline QDBusPendingReply<> AttachDevice(const QString &in0, const QString &in1, bool in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);
        return asyncCallWithArgumentList(QStringLiteral("AttachDevice"), argumentList);
    }

    inline void AttachDeviceQueued(const QString &in0, const QString &in1, bool in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);

        CallQueued(QStringLiteral("AttachDevice"), argumentList);
    }


    inline QDBusPendingReply<QString> CanHibernate()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanHibernate"), argumentList);
    }



    inline QDBusPendingReply<QString> CanHybridSleep()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanHybridSleep"), argumentList);
    }



    inline QDBusPendingReply<QString> CanPowerOff()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanPowerOff"), argumentList);
    }



    inline QDBusPendingReply<QString> CanReboot()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanReboot"), argumentList);
    }



    inline QDBusPendingReply<QString> CanRebootToFirmwareSetup()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanRebootToFirmwareSetup"), argumentList);
    }



    inline QDBusPendingReply<QString> CanSuspend()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanSuspend"), argumentList);
    }



    inline QDBusPendingReply<bool> CancelScheduledShutdown()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CancelScheduledShutdown"), argumentList);
    }



    inline QDBusPendingReply<> FlushDevices(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("FlushDevices"), argumentList);
    }

    inline void FlushDevicesQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("FlushDevices"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> GetSeat(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetSeat"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetSession(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetSession"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetSessionByPID(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetSessionByPID"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetUser(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUser"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetUserByPID(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUserByPID"), argumentList);
    }



    inline QDBusPendingReply<> Hibernate(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("Hibernate"), argumentList);
    }

    inline void HibernateQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("Hibernate"), argumentList);
    }


    inline QDBusPendingReply<> HybridSleep(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("HybridSleep"), argumentList);
    }

    inline void HybridSleepQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("HybridSleep"), argumentList);
    }


    inline QDBusPendingReply<QDBusUnixFileDescriptor> Inhibit(const QString &in0, const QString &in1, const QString &in2, const QString &in3)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2) << QVariant::fromValue(in3);
        return asyncCallWithArgumentList(QStringLiteral("Inhibit"), argumentList);
    }



    inline QDBusPendingReply<> KillSession(const QString &in0, const QString &in1, int in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);
        return asyncCallWithArgumentList(QStringLiteral("KillSession"), argumentList);
    }

    inline void KillSessionQueued(const QString &in0, const QString &in1, int in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);

        CallQueued(QStringLiteral("KillSession"), argumentList);
    }


    inline QDBusPendingReply<> KillUser(uint in0, int in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("KillUser"), argumentList);
    }

    inline void KillUserQueued(uint in0, int in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("KillUser"), argumentList);
    }


    inline QDBusPendingReply<> LockSession(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("LockSession"), argumentList);
    }

    inline void LockSessionQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("LockSession"), argumentList);
    }


    inline QDBusPendingReply<> LockSessions()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("LockSessions"), argumentList);
    }

    inline void LockSessionsQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("LockSessions"), argumentList);
    }


    inline QDBusPendingReply<> PowerOff(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("PowerOff"), argumentList);
    }

    inline void PowerOffQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("PowerOff"), argumentList);
    }


    inline QDBusPendingReply<> Reboot(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("Reboot"), argumentList);
    }

    inline void RebootQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("Reboot"), argumentList);
    }


    inline QDBusPendingReply<> ReleaseSession(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("ReleaseSession"), argumentList);
    }

    inline void ReleaseSessionQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("ReleaseSession"), argumentList);
    }


    inline QDBusPendingReply<> ScheduleShutdown(const QString &in0, qulonglong in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ScheduleShutdown"), argumentList);
    }

    inline void ScheduleShutdownQueued(const QString &in0, qulonglong in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("ScheduleShutdown"), argumentList);
    }


    inline QDBusPendingReply<> SetRebootToFirmwareSetup(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetRebootToFirmwareSetup"), argumentList);
    }

    inline void SetRebootToFirmwareSetupQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetRebootToFirmwareSetup"), argumentList);
    }


    inline QDBusPendingReply<> SetUserLinger(uint in0, bool in1, bool in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);
        return asyncCallWithArgumentList(QStringLiteral("SetUserLinger"), argumentList);
    }

    inline void SetUserLingerQueued(uint in0, bool in1, bool in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);

        CallQueued(QStringLiteral("SetUserLinger"), argumentList);
    }


    inline QDBusPendingReply<> SetWallMessage(const QString &in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetWallMessage"), argumentList);
    }

    inline void SetWallMessageQueued(const QString &in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetWallMessage"), argumentList);
    }


    inline QDBusPendingReply<> Suspend(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("Suspend"), argumentList);
    }

    inline void SuspendQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("Suspend"), argumentList);
    }


    inline QDBusPendingReply<> TerminateSeat(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("TerminateSeat"), argumentList);
    }

    inline void TerminateSeatQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("TerminateSeat"), argumentList);
    }


    inline QDBusPendingReply<> TerminateSession(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("TerminateSession"), argumentList);
    }

    inline void TerminateSessionQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("TerminateSession"), argumentList);
    }


    inline QDBusPendingReply<> TerminateUser(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("TerminateUser"), argumentList);
    }

    inline void TerminateUserQueued(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("TerminateUser"), argumentList);
    }


    inline QDBusPendingReply<> UnlockSession(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("UnlockSession"), argumentList);
    }

    inline void UnlockSessionQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("UnlockSession"), argumentList);
    }


    inline QDBusPendingReply<> UnlockSessions()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("UnlockSessions"), argumentList);
    }

    inline void UnlockSessionsQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("UnlockSessions"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void PrepareForShutdown(bool in0);
    void PrepareForSleep(bool in0);
    void SeatNew(const QString &in0, const QDBusObjectPath &in1);
    void SeatRemoved(const QString &in0, const QDBusObjectPath &in1);
    void SessionNew(const QString &in0, const QDBusObjectPath &in1);
    void SessionRemoved(const QString &in0, const QDBusObjectPath &in1);
    void UserNew(uint in0, const QDBusObjectPath &in1);
    void UserRemoved(uint in0, const QDBusObjectPath &in1);
    // begin property changed signals
    void BlockInhibitedChanged(const QString & value) const;
    void DelayInhibitedChanged(const QString & value) const;
    void DockedChanged(bool  value) const;
    void EnableWallMessagesChanged(bool  value) const;
    void HandleHibernateKeyChanged(const QString & value) const;
    void HandleLidSwitchChanged(const QString & value) const;
    void HandleLidSwitchDockedChanged(const QString & value) const;
    void HandlePowerKeyChanged(const QString & value) const;
    void HandleSuspendKeyChanged(const QString & value) const;
    void HoldoffTimeoutUSecChanged(qulonglong  value) const;
    void IdleActionChanged(const QString & value) const;
    void IdleActionUSecChanged(qulonglong  value) const;
    void IdleHintChanged(bool  value) const;
    void IdleSinceHintChanged(qulonglong  value) const;
    void IdleSinceHintMonotonicChanged(qulonglong  value) const;
    void InhibitDelayMaxUSecChanged(qulonglong  value) const;
    void InhibitorsMaxChanged(qulonglong  value) const;
    void KillExcludeUsersChanged(const QStringList & value) const;
    void KillOnlyUsersChanged(const QStringList & value) const;
    void KillUserProcessesChanged(bool  value) const;
    void NAutoVTsChanged(uint  value) const;
    void NCurrentInhibitorsChanged(qulonglong  value) const;
    void NCurrentSessionsChanged(qulonglong  value) const;
    void PreparingForShutdownChanged(bool  value) const;
    void PreparingForSleepChanged(bool  value) const;
    void RebootToFirmwareSetupChanged(bool  value) const;
    void RemoveIPCChanged(bool  value) const;
    void RuntimeDirectorySizeChanged(qulonglong  value) const;
    void SessionsMaxChanged(qulonglong  value) const;
    void UserTasksMaxChanged(qulonglong  value) const;
    void WallMessageChanged(const QString & value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __Login1ManagerPrivate *d_ptr;
};

namespace org {
  namespace freedesktop {
    namespace login1 {
      typedef ::__Login1Manager Manager;
    }
  }
}
#endif
