/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.SessionManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "sessionmanager1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SessionManager1Adaptor
 */

SessionManager1Adaptor::SessionManager1Adaptor(SessionManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SessionManager1Adaptor::~SessionManager1Adaptor()
{
    // destructor
}

QDBusObjectPath SessionManager1Adaptor::currentSessionPath() const
{
    // get the value of property CurrentSessionPath
    return qvariant_cast< QDBusObjectPath >(parent()->property("CurrentSessionPath"));
}

QString SessionManager1Adaptor::currentUid() const
{
    // get the value of property CurrentUid
    return qvariant_cast< QString >(parent()->property("CurrentUid"));
}

bool SessionManager1Adaptor::locked() const
{
    // get the value of property Locked
    return qvariant_cast< bool >(parent()->property("Locked"));
}

int SessionManager1Adaptor::stage() const
{
    // get the value of property Stage
    return qvariant_cast< int >(parent()->property("Stage"));
}

bool SessionManager1Adaptor::AllowSessionDaemonRun()
{
    // handle method call org.deepin.dde.SessionManager1.AllowSessionDaemonRun
    return parent()->AllowSessionDaemonRun();
}

bool SessionManager1Adaptor::CanHibernate()
{
    // handle method call org.deepin.dde.SessionManager1.CanHibernate
    return parent()->CanHibernate();
}

bool SessionManager1Adaptor::CanLogout()
{
    // handle method call org.deepin.dde.SessionManager1.CanLogout
    return parent()->CanLogout();
}

bool SessionManager1Adaptor::CanReboot()
{
    // handle method call org.deepin.dde.SessionManager1.CanReboot
    return parent()->CanReboot();
}

bool SessionManager1Adaptor::CanShutdown()
{
    // handle method call org.deepin.dde.SessionManager1.CanShutdown
    return parent()->CanShutdown();
}

bool SessionManager1Adaptor::CanSuspend()
{
    // handle method call org.deepin.dde.SessionManager1.CanSuspend
    return parent()->CanSuspend();
}

QList<QDBusObjectPath> SessionManager1Adaptor::GetInhibitors()
{
    // handle method call org.deepin.dde.SessionManager1.GetInhibitors
    return parent()->GetInhibitors();
}

uint SessionManager1Adaptor::Inhibit(const QString &appId, uint toplevelXid, const QString &reason, uint flags)
{
    // handle method call org.deepin.dde.SessionManager1.Inhibit
    return parent()->Inhibit(appId, toplevelXid, reason, flags);
}

bool SessionManager1Adaptor::IsInhibited(uint flags)
{
    // handle method call org.deepin.dde.SessionManager1.IsInhibited
    return parent()->IsInhibited(flags);
}

void SessionManager1Adaptor::Logout()
{
    // handle method call org.deepin.dde.SessionManager1.Logout
    parent()->Logout();
}

void SessionManager1Adaptor::PowerOffChoose()
{
    // handle method call org.deepin.dde.SessionManager1.PowerOffChoose
    parent()->PowerOffChoose();
}

void SessionManager1Adaptor::Reboot()
{
    // handle method call org.deepin.dde.SessionManager1.Reboot
    parent()->Reboot();
}

bool SessionManager1Adaptor::Register(const QString &id)
{
    // handle method call org.deepin.dde.SessionManager1.Register
    return parent()->Register(id);
}

void SessionManager1Adaptor::RequestHibernate()
{
    // handle method call org.deepin.dde.SessionManager1.RequestHibernate
    parent()->RequestHibernate();
}

void SessionManager1Adaptor::RequestLock()
{
    // handle method call org.deepin.dde.SessionManager1.RequestLock
    parent()->RequestLock();
}

void SessionManager1Adaptor::RequestLogout()
{
    // handle method call org.deepin.dde.SessionManager1.RequestLogout
    parent()->RequestLogout();
}

void SessionManager1Adaptor::RequestReboot()
{
    // handle method call org.deepin.dde.SessionManager1.RequestReboot
    parent()->RequestReboot();
}

void SessionManager1Adaptor::RequestShutdown()
{
    // handle method call org.deepin.dde.SessionManager1.RequestShutdown
    parent()->RequestShutdown();
}

void SessionManager1Adaptor::RequestSuspend()
{
    // handle method call org.deepin.dde.SessionManager1.RequestSuspend
    parent()->RequestSuspend();
}

void SessionManager1Adaptor::SetLocked(bool value)
{
    // handle method call org.deepin.dde.SessionManager1.SetLocked
    parent()->SetLocked(value);
}

void SessionManager1Adaptor::Shutdown()
{
    // handle method call org.deepin.dde.SessionManager1.Shutdown
    parent()->Shutdown();
}

void SessionManager1Adaptor::ToggleDebug()
{
    // handle method call org.deepin.dde.SessionManager1.ToggleDebug
    parent()->ToggleDebug();
}

void SessionManager1Adaptor::Uninhibit(uint inhibitCookie)
{
    // handle method call org.deepin.dde.SessionManager1.Uninhibit
    parent()->Uninhibit(inhibitCookie);
}


#include "moc_sessionmanager1adaptor.cpp"
