/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.WMSwitcher1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "wmswitcher1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class WMSwitcher1Adaptor
 */

WMSwitcher1Adaptor::WMSwitcher1Adaptor(WMSwitcher *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

WMSwitcher1Adaptor::~WMSwitcher1Adaptor()
{
    // destructor
}

bool WMSwitcher1Adaptor::AllowSwitch()
{
    // handle method call org.deepin.dde.WMSwitcher1.AllowSwitch
    return parent()->AllowSwitch();
}

QString WMSwitcher1Adaptor::CurrentWM()
{
    // handle method call org.deepin.dde.WMSwitcher1.CurrentWM
    return parent()->CurrentWM();
}

void WMSwitcher1Adaptor::RequestSwitchWM()
{
    // handle method call org.deepin.dde.WMSwitcher1.RequestSwitchWM
    parent()->RequestSwitchWM();
}


#include "moc_wmswitcher1adaptor.cpp"
