/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Bluetooth -p /build/deepin-session/src/dde-session/dbusinterface/org_deepin_dde_Bluetooth1 /build/deepin-session/src/dde-session/dbus/interface/org.deepin.dde.Bluetooth1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_DEEPIN_DDE_BLUETOOTH1_H
#define ORG_DEEPIN_DDE_BLUETOOTH1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.deepin.dde.Bluetooth1
 */
class __BluetoothPrivate;
class __Bluetooth : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Bluetooth1"; }

public:
    explicit __Bluetooth(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Bluetooth();

    Q_PROPERTY(bool CanSendFile READ canSendFile NOTIFY CanSendFileChanged)
    bool canSendFile();

    Q_PROPERTY(uint State READ state NOTIFY StateChanged)
    uint state();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> ClearUnpairedDevice()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ClearUnpairedDevice"), argumentList);
    }

    inline void ClearUnpairedDeviceQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("ClearUnpairedDevice"), argumentList);
    }


    inline QDBusPendingReply<> ConnectDevice(const QDBusObjectPath &devPath, const QDBusObjectPath &adapterPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(devPath) << QVariant::fromValue(adapterPath);
        return asyncCallWithArgumentList(QStringLiteral("ConnectDevice"), argumentList);
    }

    inline void ConnectDeviceQueued(const QDBusObjectPath &devPath, const QDBusObjectPath &adapterPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(devPath) << QVariant::fromValue(adapterPath);

        CallQueued(QStringLiteral("ConnectDevice"), argumentList);
    }


    inline QDBusPendingReply<QString> DebugInfo()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("DebugInfo"), argumentList);
    }



    inline QDBusPendingReply<> DisconnectAudioDevices()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("DisconnectAudioDevices"), argumentList);
    }

    inline void DisconnectAudioDevicesQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("DisconnectAudioDevices"), argumentList);
    }


    inline QDBusPendingReply<> DisconnectDevice(const QDBusObjectPath &devPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(devPath);
        return asyncCallWithArgumentList(QStringLiteral("DisconnectDevice"), argumentList);
    }

    inline void DisconnectDeviceQueued(const QDBusObjectPath &devPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(devPath);

        CallQueued(QStringLiteral("DisconnectDevice"), argumentList);
    }


    inline QDBusPendingReply<QString> GetAdapters()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetAdapters"), argumentList);
    }



    inline QDBusPendingReply<QString> GetDevices(const QDBusObjectPath &adapterPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath);
        return asyncCallWithArgumentList(QStringLiteral("GetDevices"), argumentList);
    }



    inline QDBusPendingReply<> RegisterAgent(const QDBusObjectPath &agentPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(agentPath);
        return asyncCallWithArgumentList(QStringLiteral("RegisterAgent"), argumentList);
    }

    inline void RegisterAgentQueued(const QDBusObjectPath &agentPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(agentPath);

        CallQueued(QStringLiteral("RegisterAgent"), argumentList);
    }


    inline QDBusPendingReply<> RemoveDevice(const QDBusObjectPath &adapterPath, const QDBusObjectPath &devPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(devPath);
        return asyncCallWithArgumentList(QStringLiteral("RemoveDevice"), argumentList);
    }

    inline void RemoveDeviceQueued(const QDBusObjectPath &adapterPath, const QDBusObjectPath &devPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(devPath);

        CallQueued(QStringLiteral("RemoveDevice"), argumentList);
    }


    inline QDBusPendingReply<> RequestDiscovery(const QDBusObjectPath &adapterPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath);
        return asyncCallWithArgumentList(QStringLiteral("RequestDiscovery"), argumentList);
    }

    inline void RequestDiscoveryQueued(const QDBusObjectPath &adapterPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath);

        CallQueued(QStringLiteral("RequestDiscovery"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterAlias(const QDBusObjectPath &adapterPath, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(alias);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterAlias"), argumentList);
    }

    inline void SetAdapterAliasQueued(const QDBusObjectPath &adapterPath, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(alias);

        CallQueued(QStringLiteral("SetAdapterAlias"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterDiscoverable(const QDBusObjectPath &adapterPath, bool discoverable)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(discoverable);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterDiscoverable"), argumentList);
    }

    inline void SetAdapterDiscoverableQueued(const QDBusObjectPath &adapterPath, bool discoverable)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(discoverable);

        CallQueued(QStringLiteral("SetAdapterDiscoverable"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterDiscoverableTimeout(const QDBusObjectPath &adapterPath, uint discoverableTimeout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(discoverableTimeout);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterDiscoverableTimeout"), argumentList);
    }

    inline void SetAdapterDiscoverableTimeoutQueued(const QDBusObjectPath &adapterPath, uint discoverableTimeout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(discoverableTimeout);

        CallQueued(QStringLiteral("SetAdapterDiscoverableTimeout"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterDiscovering(const QDBusObjectPath &adapterPath, bool discovering)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(discovering);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterDiscovering"), argumentList);
    }

    inline void SetAdapterDiscoveringQueued(const QDBusObjectPath &adapterPath, bool discovering)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(discovering);

        CallQueued(QStringLiteral("SetAdapterDiscovering"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterPowered(const QDBusObjectPath &adapterPath, bool powered)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(powered);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterPowered"), argumentList);
    }

    inline void SetAdapterPoweredQueued(const QDBusObjectPath &adapterPath, bool powered)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapterPath) << QVariant::fromValue(powered);

        CallQueued(QStringLiteral("SetAdapterPowered"), argumentList);
    }


    inline QDBusPendingReply<> SetDeviceAlias(const QDBusObjectPath &device, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(alias);
        return asyncCallWithArgumentList(QStringLiteral("SetDeviceAlias"), argumentList);
    }

    inline void SetDeviceAliasQueued(const QDBusObjectPath &device, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(alias);

        CallQueued(QStringLiteral("SetDeviceAlias"), argumentList);
    }


    inline QDBusPendingReply<> SetDeviceTrusted(const QDBusObjectPath &device, bool trusted)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(trusted);
        return asyncCallWithArgumentList(QStringLiteral("SetDeviceTrusted"), argumentList);
    }

    inline void SetDeviceTrustedQueued(const QDBusObjectPath &device, bool trusted)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(trusted);

        CallQueued(QStringLiteral("SetDeviceTrusted"), argumentList);
    }


    inline QDBusPendingReply<> UnregisterAgent(const QDBusObjectPath &agentPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(agentPath);
        return asyncCallWithArgumentList(QStringLiteral("UnregisterAgent"), argumentList);
    }

    inline void UnregisterAgentQueued(const QDBusObjectPath &agentPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(agentPath);

        CallQueued(QStringLiteral("UnregisterAgent"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void AdapterAdded(const QString &adapterJSON);
    void AdapterPropertiesChanged(const QString &adapterJSON);
    void AdapterRemoved(const QString &adapterJSON);
    void DeviceAdded(const QString &devJSON);
    void DevicePropertiesChanged(const QString &devJSON);
    void DeviceRemoved(const QString &devJSON);
    // begin property changed signals
    void CanSendFileChanged(bool  value) const;
    void StateChanged(uint  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __BluetoothPrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__Bluetooth Bluetooth1;
    }
  }
}
#endif
