/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Session1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef SESSION_H
#define SESSION_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.deepin.dde.Session1
 */
class OrgDeepinDdeSession1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Session1"; }

public:
    OrgDeepinDdeSession1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgDeepinDdeSession1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> GetSessionPath()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetSessionPath"), argumentList);
    }

    inline QDBusPendingReply<int> GetSessionPid()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetSessionPid"), argumentList);
    }

    inline QDBusPendingReply<> Logout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Logout"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace deepin {
    namespace dde {
      using Session1 = ::OrgDeepinDdeSession1Interface;
    }
  }
}

#endif
