/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Systemd1Job -p /build/deepin-session/src/dde-session/dbusinterface/org_freedesktop_systemd1_Job /build/deepin-session/src/dde-session/dbus/interface/org.freedesktop.systemd1.Job.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_FREEDESKTOP_SYSTEMD1_JOB_H
#define ORG_FREEDESKTOP_SYSTEMD1_JOB_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.freedesktop.systemd1.Job
 */
class __Systemd1JobPrivate;
class __Systemd1Job : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.systemd1.Job"; }

public:
    explicit __Systemd1Job(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Systemd1Job();

    Q_PROPERTY(uint Id READ id NOTIFY IdChanged)
    uint id();

    Q_PROPERTY(QString JobType READ jobType NOTIFY JobTypeChanged)
    QString jobType();

    Q_PROPERTY(QString State READ state NOTIFY StateChanged)
    QString state();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Cancel()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Cancel"), argumentList);
    }

    inline void CancelQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Cancel"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals
    void IdChanged(uint  value) const;
    void JobTypeChanged(const QString & value) const;
    void StateChanged(const QString & value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __Systemd1JobPrivate *d_ptr;
};

namespace org {
  namespace freedesktop {
    namespace systemd1 {
      typedef ::__Systemd1Job Job;
    }
  }
}
#endif
