/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_Audio1_Sink.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_deepin_dde_Audio1_Sink.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_Audio1_Sink.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6__SinkE_t {};
} // unnamed namespace

template <> constexpr inline auto __Sink::qt_create_metaobjectdata<qt_meta_tag_ZN6__SinkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Sink",
        "BalanceChanged",
        "",
        "value",
        "BaseVolumeChanged",
        "CardChanged",
        "DescriptionChanged",
        "FadeChanged",
        "MuteChanged",
        "NameChanged",
        "SupportBalanceChanged",
        "VolumeChanged",
        "GetMeter",
        "QDBusPendingReply<QDBusObjectPath>",
        "SetBalance",
        "QDBusPendingReply<>",
        "in0",
        "in1",
        "SetBalanceQueued",
        "SetFade",
        "SetFadeQueued",
        "SetMute",
        "SetMuteQueued",
        "SetPort",
        "SetPortQueued",
        "SetVolume",
        "SetVolumeQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Balance",
        "BaseVolume",
        "Card",
        "Description",
        "Fade",
        "Mute",
        "Name",
        "SupportBalance",
        "Volume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BalanceChanged'
        QtMocHelpers::SignalData<void(double) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'BaseVolumeChanged'
        QtMocHelpers::SignalData<void(double) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'CardChanged'
        QtMocHelpers::SignalData<void(uint) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'DescriptionChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'FadeChanged'
        QtMocHelpers::SignalData<void(double) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'MuteChanged'
        QtMocHelpers::SignalData<void(bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'SupportBalanceChanged'
        QtMocHelpers::SignalData<void(bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'VolumeChanged'
        QtMocHelpers::SignalData<void(double) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Slot 'GetMeter'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>()>(12, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'SetBalance'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double, bool)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Double, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'SetBalanceQueued'
        QtMocHelpers::SlotData<void(double, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'SetFade'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double)>(19, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'SetFadeQueued'
        QtMocHelpers::SlotData<void(double)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'SetMute'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(21, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'SetMuteQueued'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'SetPort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(23, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'SetPortQueued'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'SetVolume'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double, bool)>(25, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Double, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'SetVolumeQueued'
        QtMocHelpers::SlotData<void(double, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 35 }, { 0x80000000 | 36, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Balance'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
        // property 'BaseVolume'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags, 1),
        // property 'Card'
        QtMocHelpers::PropertyData<uint>(39, QMetaType::UInt, QMC::DefaultPropertyFlags, 2),
        // property 'Description'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'Fade'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags, 4),
        // property 'Mute'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'SupportBalance'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'Volume'
        QtMocHelpers::PropertyData<double>(45, QMetaType::Double, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Sink, qt_meta_tag_ZN6__SinkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Sink::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6__SinkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6__SinkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6__SinkE_t>.metaTypes,
    nullptr
} };

void __Sink::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Sink *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BalanceChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 1: _t->BaseVolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->CardChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->DescriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->FadeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->MuteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->SupportBalanceChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->VolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetMeter();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->SetBalance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->SetBalanceQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: { QDBusPendingReply<> _r = _t->SetFade((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->SetFadeQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: { QDBusPendingReply<> _r = _t->SetMute((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->SetMuteQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: { QDBusPendingReply<> _r = _t->SetPort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->SetPortQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: { QDBusPendingReply<> _r = _t->SetVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->SetVolumeQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 21: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 22: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(double ) const>(_a, &__Sink::BalanceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(double ) const>(_a, &__Sink::BaseVolumeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(uint ) const>(_a, &__Sink::CardChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(const QString & ) const>(_a, &__Sink::DescriptionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(double ) const>(_a, &__Sink::FadeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(bool ) const>(_a, &__Sink::MuteChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(const QString & ) const>(_a, &__Sink::NameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(bool ) const>(_a, &__Sink::SupportBalanceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Sink::*)(double ) const>(_a, &__Sink::VolumeChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->balance(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->baseVolume(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->card(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->fade(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->mute(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->supportBalance(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
}

const QMetaObject *__Sink::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Sink::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6__SinkE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Sink::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void __Sink::BalanceChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __Sink::BaseVolumeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __Sink::CardChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __Sink::DescriptionChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __Sink::FadeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __Sink::MuteChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __Sink::NameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __Sink::SupportBalanceChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __Sink::VolumeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __Sink *>(this), &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
