/****************************************************************************
** Meta object code from reading C++ file 'org_freedesktop_login1_Manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_freedesktop_login1_Manager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_freedesktop_login1_Manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15__Login1ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto __Login1Manager::qt_create_metaobjectdata<qt_meta_tag_ZN15__Login1ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Login1Manager",
        "PrepareForShutdown",
        "",
        "in0",
        "PrepareForSleep",
        "SeatNew",
        "QDBusObjectPath",
        "in1",
        "SeatRemoved",
        "SessionNew",
        "SessionRemoved",
        "UserNew",
        "UserRemoved",
        "BlockInhibitedChanged",
        "value",
        "DelayInhibitedChanged",
        "DockedChanged",
        "EnableWallMessagesChanged",
        "HandleHibernateKeyChanged",
        "HandleLidSwitchChanged",
        "HandleLidSwitchDockedChanged",
        "HandlePowerKeyChanged",
        "HandleSuspendKeyChanged",
        "HoldoffTimeoutUSecChanged",
        "IdleActionChanged",
        "IdleActionUSecChanged",
        "IdleHintChanged",
        "IdleSinceHintChanged",
        "IdleSinceHintMonotonicChanged",
        "InhibitDelayMaxUSecChanged",
        "InhibitorsMaxChanged",
        "KillExcludeUsersChanged",
        "KillOnlyUsersChanged",
        "KillUserProcessesChanged",
        "NAutoVTsChanged",
        "NCurrentInhibitorsChanged",
        "NCurrentSessionsChanged",
        "PreparingForShutdownChanged",
        "PreparingForSleepChanged",
        "RebootToFirmwareSetupChanged",
        "RemoveIPCChanged",
        "RuntimeDirectorySizeChanged",
        "SessionsMaxChanged",
        "UserTasksMaxChanged",
        "WallMessageChanged",
        "ActivateSession",
        "QDBusPendingReply<>",
        "ActivateSessionQueued",
        "ActivateSessionOnSeat",
        "ActivateSessionOnSeatQueued",
        "AttachDevice",
        "in2",
        "AttachDeviceQueued",
        "CanHibernate",
        "QDBusPendingReply<QString>",
        "CanHybridSleep",
        "CanPowerOff",
        "CanReboot",
        "CanRebootToFirmwareSetup",
        "CanSuspend",
        "CancelScheduledShutdown",
        "QDBusPendingReply<bool>",
        "FlushDevices",
        "FlushDevicesQueued",
        "GetSeat",
        "QDBusPendingReply<QDBusObjectPath>",
        "GetSession",
        "GetSessionByPID",
        "GetUser",
        "GetUserByPID",
        "Hibernate",
        "HibernateQueued",
        "HybridSleep",
        "HybridSleepQueued",
        "Inhibit",
        "QDBusPendingReply<QDBusUnixFileDescriptor>",
        "in3",
        "KillSession",
        "KillSessionQueued",
        "KillUser",
        "KillUserQueued",
        "LockSession",
        "LockSessionQueued",
        "LockSessions",
        "LockSessionsQueued",
        "PowerOff",
        "PowerOffQueued",
        "Reboot",
        "RebootQueued",
        "ReleaseSession",
        "ReleaseSessionQueued",
        "ScheduleShutdown",
        "ScheduleShutdownQueued",
        "SetRebootToFirmwareSetup",
        "SetRebootToFirmwareSetupQueued",
        "SetUserLinger",
        "SetUserLingerQueued",
        "SetWallMessage",
        "SetWallMessageQueued",
        "Suspend",
        "SuspendQueued",
        "TerminateSeat",
        "TerminateSeatQueued",
        "TerminateSession",
        "TerminateSessionQueued",
        "TerminateUser",
        "TerminateUserQueued",
        "UnlockSession",
        "UnlockSessionQueued",
        "UnlockSessions",
        "UnlockSessionsQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "BlockInhibited",
        "DelayInhibited",
        "Docked",
        "EnableWallMessages",
        "HandleHibernateKey",
        "HandleLidSwitch",
        "HandleLidSwitchDocked",
        "HandlePowerKey",
        "HandleSuspendKey",
        "HoldoffTimeoutUSec",
        "IdleAction",
        "IdleActionUSec",
        "IdleHint",
        "IdleSinceHint",
        "IdleSinceHintMonotonic",
        "InhibitDelayMaxUSec",
        "InhibitorsMax",
        "KillExcludeUsers",
        "KillOnlyUsers",
        "KillUserProcesses",
        "NAutoVTs",
        "NCurrentInhibitors",
        "NCurrentSessions",
        "PreparingForShutdown",
        "PreparingForSleep",
        "RebootToFirmwareSetup",
        "RemoveIPC",
        "RuntimeDirectorySize",
        "SessionsMax",
        "UserTasksMax",
        "WallMessage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PrepareForShutdown'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'PrepareForSleep'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'SeatNew'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'SeatRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'SessionNew'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'SessionRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'UserNew'
        QtMocHelpers::SignalData<void(uint, const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'UserRemoved'
        QtMocHelpers::SignalData<void(uint, const QDBusObjectPath &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'BlockInhibitedChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'DelayInhibitedChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'DockedChanged'
        QtMocHelpers::SignalData<void(bool) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'EnableWallMessagesChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'HandleHibernateKeyChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'HandleLidSwitchChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'HandleLidSwitchDockedChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'HandlePowerKeyChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'HandleSuspendKeyChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'HoldoffTimeoutUSecChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'IdleActionChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'IdleActionUSecChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'IdleHintChanged'
        QtMocHelpers::SignalData<void(bool) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'IdleSinceHintChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'IdleSinceHintMonotonicChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'InhibitDelayMaxUSecChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'InhibitorsMaxChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'KillExcludeUsersChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'KillOnlyUsersChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'KillUserProcessesChanged'
        QtMocHelpers::SignalData<void(bool) const>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'NAutoVTsChanged'
        QtMocHelpers::SignalData<void(uint) const>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Signal 'NCurrentInhibitorsChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'NCurrentSessionsChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'PreparingForShutdownChanged'
        QtMocHelpers::SignalData<void(bool) const>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'PreparingForSleepChanged'
        QtMocHelpers::SignalData<void(bool) const>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'RebootToFirmwareSetupChanged'
        QtMocHelpers::SignalData<void(bool) const>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'RemoveIPCChanged'
        QtMocHelpers::SignalData<void(bool) const>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'RuntimeDirectorySizeChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'SessionsMaxChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'UserTasksMaxChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 14 },
        }}),
        // Signal 'WallMessageChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'ActivateSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivateSessionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivateSessionOnSeat'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(48, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'ActivateSessionOnSeatQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'AttachDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, bool)>(50, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'AttachDeviceQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'CanHibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(53, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'CanHybridSleep'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(55, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'CanPowerOff'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(56, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'CanReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(57, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'CanRebootToFirmwareSetup'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(58, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'CanSuspend'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(59, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'CancelScheduledShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(60, 2, QMC::AccessPublic, 0x80000000 | 61),
        // Slot 'FlushDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(62, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'FlushDevicesQueued'
        QtMocHelpers::SlotData<void(bool)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'GetSeat'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(64, 2, QMC::AccessPublic, 0x80000000 | 65, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetSession'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(66, 2, QMC::AccessPublic, 0x80000000 | 65, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetSessionByPID'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(uint)>(67, 2, QMC::AccessPublic, 0x80000000 | 65, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'GetUser'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(uint)>(68, 2, QMC::AccessPublic, 0x80000000 | 65, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'GetUserByPID'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(uint)>(69, 2, QMC::AccessPublic, 0x80000000 | 65, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'Hibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(70, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'HibernateQueued'
        QtMocHelpers::SlotData<void(bool)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'HybridSleep'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(72, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'HybridSleepQueued'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'Inhibit'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor>(const QString &, const QString &, const QString &, const QString &)>(74, 2, QMC::AccessPublic, 0x80000000 | 75, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 }, { QMetaType::QString, 51 }, { QMetaType::QString, 76 },
        }}),
        // Slot 'KillSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, int)>(77, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 }, { QMetaType::Int, 51 },
        }}),
        // Slot 'KillSessionQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 }, { QMetaType::Int, 51 },
        }}),
        // Slot 'KillUser'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, int)>(79, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::UInt, 3 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'KillUserQueued'
        QtMocHelpers::SlotData<void(uint, int)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'LockSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(81, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'LockSessionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'LockSessions'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(83, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'LockSessionsQueued'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PowerOff'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(85, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'PowerOffQueued'
        QtMocHelpers::SlotData<void(bool)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'Reboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(87, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'RebootQueued'
        QtMocHelpers::SlotData<void(bool)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'ReleaseSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(89, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ReleaseSessionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ScheduleShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, qulonglong)>(91, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 }, { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'ScheduleShutdownQueued'
        QtMocHelpers::SlotData<void(const QString &, qulonglong)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'SetRebootToFirmwareSetup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(93, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'SetRebootToFirmwareSetupQueued'
        QtMocHelpers::SlotData<void(bool)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'SetUserLinger'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, bool, bool)>(95, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::UInt, 3 }, { QMetaType::Bool, 7 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'SetUserLingerQueued'
        QtMocHelpers::SlotData<void(uint, bool, bool)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::Bool, 7 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'SetWallMessage'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(97, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'SetWallMessageQueued'
        QtMocHelpers::SlotData<void(const QString &, bool)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'Suspend'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(99, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'SuspendQueued'
        QtMocHelpers::SlotData<void(bool)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'TerminateSeat'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(101, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'TerminateSeatQueued'
        QtMocHelpers::SlotData<void(const QString &)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'TerminateSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(103, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'TerminateSessionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(104, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'TerminateUser'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(105, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'TerminateUserQueued'
        QtMocHelpers::SlotData<void(uint)>(106, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'UnlockSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(107, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'UnlockSessionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(108, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'UnlockSessions'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(109, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'UnlockSessionsQueued'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 112 }, { 0x80000000 | 113, 114 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(115, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 116, 117 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 119 }, { 0x80000000 | 120, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'BlockInhibited'
        QtMocHelpers::PropertyData<QString>(121, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'DelayInhibited'
        QtMocHelpers::PropertyData<QString>(122, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'Docked'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'EnableWallMessages'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'HandleHibernateKey'
        QtMocHelpers::PropertyData<QString>(125, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'HandleLidSwitch'
        QtMocHelpers::PropertyData<QString>(126, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'HandleLidSwitchDocked'
        QtMocHelpers::PropertyData<QString>(127, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'HandlePowerKey'
        QtMocHelpers::PropertyData<QString>(128, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
        // property 'HandleSuspendKey'
        QtMocHelpers::PropertyData<QString>(129, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'HoldoffTimeoutUSec'
        QtMocHelpers::PropertyData<qulonglong>(130, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 17),
        // property 'IdleAction'
        QtMocHelpers::PropertyData<QString>(131, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'IdleActionUSec'
        QtMocHelpers::PropertyData<qulonglong>(132, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 19),
        // property 'IdleHint'
        QtMocHelpers::PropertyData<bool>(133, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'IdleSinceHint'
        QtMocHelpers::PropertyData<qulonglong>(134, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 21),
        // property 'IdleSinceHintMonotonic'
        QtMocHelpers::PropertyData<qulonglong>(135, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 22),
        // property 'InhibitDelayMaxUSec'
        QtMocHelpers::PropertyData<qulonglong>(136, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 23),
        // property 'InhibitorsMax'
        QtMocHelpers::PropertyData<qulonglong>(137, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 24),
        // property 'KillExcludeUsers'
        QtMocHelpers::PropertyData<QStringList>(138, QMetaType::QStringList, QMC::DefaultPropertyFlags, 25),
        // property 'KillOnlyUsers'
        QtMocHelpers::PropertyData<QStringList>(139, QMetaType::QStringList, QMC::DefaultPropertyFlags, 26),
        // property 'KillUserProcesses'
        QtMocHelpers::PropertyData<bool>(140, QMetaType::Bool, QMC::DefaultPropertyFlags, 27),
        // property 'NAutoVTs'
        QtMocHelpers::PropertyData<uint>(141, QMetaType::UInt, QMC::DefaultPropertyFlags, 28),
        // property 'NCurrentInhibitors'
        QtMocHelpers::PropertyData<qulonglong>(142, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 29),
        // property 'NCurrentSessions'
        QtMocHelpers::PropertyData<qulonglong>(143, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 30),
        // property 'PreparingForShutdown'
        QtMocHelpers::PropertyData<bool>(144, QMetaType::Bool, QMC::DefaultPropertyFlags, 31),
        // property 'PreparingForSleep'
        QtMocHelpers::PropertyData<bool>(145, QMetaType::Bool, QMC::DefaultPropertyFlags, 32),
        // property 'RebootToFirmwareSetup'
        QtMocHelpers::PropertyData<bool>(146, QMetaType::Bool, QMC::DefaultPropertyFlags, 33),
        // property 'RemoveIPC'
        QtMocHelpers::PropertyData<bool>(147, QMetaType::Bool, QMC::DefaultPropertyFlags, 34),
        // property 'RuntimeDirectorySize'
        QtMocHelpers::PropertyData<qulonglong>(148, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 35),
        // property 'SessionsMax'
        QtMocHelpers::PropertyData<qulonglong>(149, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 36),
        // property 'UserTasksMax'
        QtMocHelpers::PropertyData<qulonglong>(150, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 37),
        // property 'WallMessage'
        QtMocHelpers::PropertyData<QString>(151, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Login1Manager, qt_meta_tag_ZN15__Login1ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Login1Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15__Login1ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15__Login1ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15__Login1ManagerE_t>.metaTypes,
    nullptr
} };

void __Login1Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Login1Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PrepareForShutdown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->PrepareForSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->SeatNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 3: _t->SeatRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 4: _t->SessionNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 5: _t->SessionRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 6: _t->UserNew((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 7: _t->UserRemoved((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 8: _t->BlockInhibitedChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->DelayInhibitedChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->DockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->EnableWallMessagesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->HandleHibernateKeyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->HandleLidSwitchChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->HandleLidSwitchDockedChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->HandlePowerKeyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->HandleSuspendKeyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->HoldoffTimeoutUSecChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 18: _t->IdleActionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->IdleActionUSecChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 20: _t->IdleHintChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->IdleSinceHintChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 22: _t->IdleSinceHintMonotonicChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 23: _t->InhibitDelayMaxUSecChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 24: _t->InhibitorsMaxChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 25: _t->KillExcludeUsersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 26: _t->KillOnlyUsersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 27: _t->KillUserProcessesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->NAutoVTsChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 29: _t->NCurrentInhibitorsChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 30: _t->NCurrentSessionsChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 31: _t->PreparingForShutdownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->PreparingForSleepChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->RebootToFirmwareSetupChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->RemoveIPCChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->RuntimeDirectorySizeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 36: _t->SessionsMaxChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 37: _t->UserTasksMaxChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 38: _t->WallMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: { QDBusPendingReply<> _r = _t->ActivateSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->ActivateSessionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: { QDBusPendingReply<> _r = _t->ActivateSessionOnSeat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->ActivateSessionOnSeatQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 43: { QDBusPendingReply<> _r = _t->AttachDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->AttachDeviceQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 45: { QDBusPendingReply<QString> _r = _t->CanHibernate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<QString> _r = _t->CanHybridSleep();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDBusPendingReply<QString> _r = _t->CanPowerOff();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDBusPendingReply<QString> _r = _t->CanReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 49: { QDBusPendingReply<QString> _r = _t->CanRebootToFirmwareSetup();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 50: { QDBusPendingReply<QString> _r = _t->CanSuspend();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 51: { QDBusPendingReply<bool> _r = _t->CancelScheduledShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 52: { QDBusPendingReply<> _r = _t->FlushDevices((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->FlushDevicesQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 54: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetSeat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 55: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 56: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetSessionByPID((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 57: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetUser((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 58: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetUserByPID((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 59: { QDBusPendingReply<> _r = _t->Hibernate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 60: _t->HibernateQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: { QDBusPendingReply<> _r = _t->HybridSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->HybridSleepQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: { QDBusPendingReply<QDBusUnixFileDescriptor> _r = _t->Inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 64: { QDBusPendingReply<> _r = _t->KillSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 65: _t->KillSessionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 66: { QDBusPendingReply<> _r = _t->KillUser((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 67: _t->KillUserQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 68: { QDBusPendingReply<> _r = _t->LockSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 69: _t->LockSessionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 70: { QDBusPendingReply<> _r = _t->LockSessions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 71: _t->LockSessionsQueued(); break;
        case 72: { QDBusPendingReply<> _r = _t->PowerOff((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 73: _t->PowerOffQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: { QDBusPendingReply<> _r = _t->Reboot((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->RebootQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 76: { QDBusPendingReply<> _r = _t->ReleaseSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 77: _t->ReleaseSessionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 78: { QDBusPendingReply<> _r = _t->ScheduleShutdown((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 79: _t->ScheduleShutdownQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 80: { QDBusPendingReply<> _r = _t->SetRebootToFirmwareSetup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 81: _t->SetRebootToFirmwareSetupQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 82: { QDBusPendingReply<> _r = _t->SetUserLinger((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 83: _t->SetUserLingerQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 84: { QDBusPendingReply<> _r = _t->SetWallMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 85: _t->SetWallMessageQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 86: { QDBusPendingReply<> _r = _t->Suspend((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 87: _t->SuspendQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 88: { QDBusPendingReply<> _r = _t->TerminateSeat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 89: _t->TerminateSeatQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 90: { QDBusPendingReply<> _r = _t->TerminateSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 91: _t->TerminateSessionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 92: { QDBusPendingReply<> _r = _t->TerminateUser((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 93: _t->TerminateUserQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 94: { QDBusPendingReply<> _r = _t->UnlockSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 95: _t->UnlockSessionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 96: { QDBusPendingReply<> _r = _t->UnlockSessions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 97: _t->UnlockSessionsQueued(); break;
        case 98: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 99: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 100: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 99:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool )>(_a, &__Login1Manager::PrepareForShutdown, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool )>(_a, &__Login1Manager::PrepareForSleep, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &__Login1Manager::SeatNew, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &__Login1Manager::SeatRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &__Login1Manager::SessionNew, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &__Login1Manager::SessionRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(uint , const QDBusObjectPath & )>(_a, &__Login1Manager::UserNew, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(uint , const QDBusObjectPath & )>(_a, &__Login1Manager::UserRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::BlockInhibitedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::DelayInhibitedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::DockedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::EnableWallMessagesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::HandleHibernateKeyChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::HandleLidSwitchChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::HandleLidSwitchDockedChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::HandlePowerKeyChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::HandleSuspendKeyChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::HoldoffTimeoutUSecChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::IdleActionChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::IdleActionUSecChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::IdleHintChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::IdleSinceHintChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::IdleSinceHintMonotonicChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::InhibitDelayMaxUSecChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::InhibitorsMaxChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QStringList & ) const>(_a, &__Login1Manager::KillExcludeUsersChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QStringList & ) const>(_a, &__Login1Manager::KillOnlyUsersChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::KillUserProcessesChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(uint ) const>(_a, &__Login1Manager::NAutoVTsChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::NCurrentInhibitorsChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::NCurrentSessionsChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::PreparingForShutdownChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::PreparingForSleepChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::RebootToFirmwareSetupChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(bool ) const>(_a, &__Login1Manager::RemoveIPCChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::RuntimeDirectorySizeChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::SessionsMaxChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(qulonglong ) const>(_a, &__Login1Manager::UserTasksMaxChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Manager::*)(const QString & ) const>(_a, &__Login1Manager::WallMessageChanged, 38))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->blockInhibited(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->delayInhibited(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->docked(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->enableWallMessages(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->handleHibernateKey(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->handleLidSwitch(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->handleLidSwitchDocked(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->handlePowerKey(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->handleSuspendKey(); break;
        case 9: *reinterpret_cast<qulonglong*>(_v) = _t->holdoffTimeoutUSec(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->idleAction(); break;
        case 11: *reinterpret_cast<qulonglong*>(_v) = _t->idleActionUSec(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->idleHint(); break;
        case 13: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHint(); break;
        case 14: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHintMonotonic(); break;
        case 15: *reinterpret_cast<qulonglong*>(_v) = _t->inhibitDelayMaxUSec(); break;
        case 16: *reinterpret_cast<qulonglong*>(_v) = _t->inhibitorsMax(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->killExcludeUsers(); break;
        case 18: *reinterpret_cast<QStringList*>(_v) = _t->killOnlyUsers(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->killUserProcesses(); break;
        case 20: *reinterpret_cast<uint*>(_v) = _t->nAutoVTs(); break;
        case 21: *reinterpret_cast<qulonglong*>(_v) = _t->nCurrentInhibitors(); break;
        case 22: *reinterpret_cast<qulonglong*>(_v) = _t->nCurrentSessions(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->preparingForShutdown(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->preparingForSleep(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->rebootToFirmwareSetup(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->removeIPC(); break;
        case 27: *reinterpret_cast<qulonglong*>(_v) = _t->runtimeDirectorySize(); break;
        case 28: *reinterpret_cast<qulonglong*>(_v) = _t->sessionsMax(); break;
        case 29: *reinterpret_cast<qulonglong*>(_v) = _t->userTasksMax(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->wallMessage(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setEnableWallMessages(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setWallMessage(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__Login1Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Login1Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15__Login1ManagerE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Login1Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 101)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 101;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 101)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 101;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void __Login1Manager::PrepareForShutdown(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __Login1Manager::PrepareForSleep(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __Login1Manager::SeatNew(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void __Login1Manager::SeatRemoved(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void __Login1Manager::SessionNew(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void __Login1Manager::SessionRemoved(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void __Login1Manager::UserNew(uint _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void __Login1Manager::UserRemoved(uint _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void __Login1Manager::BlockInhibitedChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __Login1Manager::DelayInhibitedChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __Login1Manager::DockedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __Login1Manager::EnableWallMessagesChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __Login1Manager::HandleHibernateKeyChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __Login1Manager::HandleLidSwitchChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __Login1Manager::HandleLidSwitchDockedChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __Login1Manager::HandlePowerKeyChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __Login1Manager::HandleSuspendKeyChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __Login1Manager::HoldoffTimeoutUSecChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void __Login1Manager::IdleActionChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void __Login1Manager::IdleActionUSecChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void __Login1Manager::IdleHintChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void __Login1Manager::IdleSinceHintChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void __Login1Manager::IdleSinceHintMonotonicChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void __Login1Manager::InhibitDelayMaxUSecChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void __Login1Manager::InhibitorsMaxChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void __Login1Manager::KillExcludeUsersChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void __Login1Manager::KillOnlyUsersChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void __Login1Manager::KillUserProcessesChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void __Login1Manager::NAutoVTsChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void __Login1Manager::NCurrentInhibitorsChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void __Login1Manager::NCurrentSessionsChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void __Login1Manager::PreparingForShutdownChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void __Login1Manager::PreparingForSleepChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void __Login1Manager::RebootToFirmwareSetupChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 33, nullptr, _t1);
}

// SIGNAL 34
void __Login1Manager::RemoveIPCChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 34, nullptr, _t1);
}

// SIGNAL 35
void __Login1Manager::RuntimeDirectorySizeChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void __Login1Manager::SessionsMaxChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void __Login1Manager::UserTasksMaxChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 37, nullptr, _t1);
}

// SIGNAL 38
void __Login1Manager::WallMessageChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Manager *>(this), &staticMetaObject, 38, nullptr, _t1);
}
QT_WARNING_POP
