/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Inhibitor1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "inhibitor1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Inhibitor1Adaptor
 */

Inhibitor1Adaptor::Inhibitor1Adaptor(Inhibitor *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Inhibitor1Adaptor::~Inhibitor1Adaptor()
{
    // destructor
}

QString Inhibitor1Adaptor::GetAppId()
{
    // handle method call org.deepin.dde.Inhibitor1.GetAppId
    return parent()->GetAppId();
}

QDBusObjectPath Inhibitor1Adaptor::GetClientId()
{
    // handle method call org.deepin.dde.Inhibitor1.GetClientId
    return parent()->GetClientId();
}

uint Inhibitor1Adaptor::GetFlags()
{
    // handle method call org.deepin.dde.Inhibitor1.GetFlags
    return parent()->GetFlags();
}

QString Inhibitor1Adaptor::GetReason()
{
    // handle method call org.deepin.dde.Inhibitor1.GetReason
    return parent()->GetReason();
}

uint Inhibitor1Adaptor::GetToplevelXid()
{
    // handle method call org.deepin.dde.Inhibitor1.GetToplevelXid
    return parent()->GetToplevelXid();
}


#include "moc_inhibitor1adaptor.cpp"
