/****************************************************************************
** Meta object code from reading C++ file 'org_freedesktop_login1_User.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_freedesktop_login1_User.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_freedesktop_login1_User.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12__Login1UserE_t {};
} // unnamed namespace

template <> constexpr inline auto __Login1User::qt_create_metaobjectdata<qt_meta_tag_ZN12__Login1UserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Login1User",
        "DisplayChanged",
        "",
        "SessionPath",
        "value",
        "GIDChanged",
        "IdleHintChanged",
        "IdleSinceHintChanged",
        "IdleSinceHintMonotonicChanged",
        "LingerChanged",
        "NameChanged",
        "RuntimePathChanged",
        "ServiceChanged",
        "SessionsChanged",
        "SessionPathList",
        "SliceChanged",
        "StateChanged",
        "TimestampChanged",
        "TimestampMonotonicChanged",
        "UIDChanged",
        "Kill",
        "QDBusPendingReply<>",
        "in0",
        "KillQueued",
        "Terminate",
        "TerminateQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Display",
        "GID",
        "IdleHint",
        "IdleSinceHint",
        "IdleSinceHintMonotonic",
        "Linger",
        "Name",
        "RuntimePath",
        "Service",
        "Sessions",
        "Slice",
        "State",
        "Timestamp",
        "TimestampMonotonic",
        "UID"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DisplayChanged'
        QtMocHelpers::SignalData<void(SessionPath) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'GIDChanged'
        QtMocHelpers::SignalData<void(uint) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Signal 'IdleHintChanged'
        QtMocHelpers::SignalData<void(bool) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'IdleSinceHintChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 4 },
        }}),
        // Signal 'IdleSinceHintMonotonicChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 4 },
        }}),
        // Signal 'LingerChanged'
        QtMocHelpers::SignalData<void(bool) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'RuntimePathChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'ServiceChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'SessionsChanged'
        QtMocHelpers::SignalData<void(SessionPathList) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 4 },
        }}),
        // Signal 'SliceChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'TimestampChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 4 },
        }}),
        // Signal 'TimestampMonotonicChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 4 },
        }}),
        // Signal 'UIDChanged'
        QtMocHelpers::SignalData<void(uint) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Slot 'Kill'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'KillQueued'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'Terminate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(24, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'TerminateQueued'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { 0x80000000 | 35, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Display'
        QtMocHelpers::PropertyData<SessionPath>(36, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'GID'
        QtMocHelpers::PropertyData<uint>(37, QMetaType::UInt, QMC::DefaultPropertyFlags, 1),
        // property 'IdleHint'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'IdleSinceHint'
        QtMocHelpers::PropertyData<qulonglong>(39, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 3),
        // property 'IdleSinceHintMonotonic'
        QtMocHelpers::PropertyData<qulonglong>(40, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 4),
        // property 'Linger'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'RuntimePath'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'Service'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'Sessions'
        QtMocHelpers::PropertyData<SessionPathList>(45, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'Slice'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'State'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'Timestamp'
        QtMocHelpers::PropertyData<qulonglong>(48, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 12),
        // property 'TimestampMonotonic'
        QtMocHelpers::PropertyData<qulonglong>(49, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 13),
        // property 'UID'
        QtMocHelpers::PropertyData<uint>(50, QMetaType::UInt, QMC::DefaultPropertyFlags, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Login1User, qt_meta_tag_ZN12__Login1UserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Login1User::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12__Login1UserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12__Login1UserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12__Login1UserE_t>.metaTypes,
    nullptr
} };

void __Login1User::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Login1User *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DisplayChanged((*reinterpret_cast<std::add_pointer_t<SessionPath>>(_a[1]))); break;
        case 1: _t->GIDChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->IdleHintChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->IdleSinceHintChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 4: _t->IdleSinceHintMonotonicChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->LingerChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->RuntimePathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->ServiceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->SessionsChanged((*reinterpret_cast<std::add_pointer_t<SessionPathList>>(_a[1]))); break;
        case 10: _t->SliceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->TimestampChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 13: _t->TimestampMonotonicChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 14: _t->UIDChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 15: { QDBusPendingReply<> _r = _t->Kill((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->KillQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: { QDBusPendingReply<> _r = _t->Terminate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->TerminateQueued(); break;
        case 19: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 20: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 21: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SessionPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SessionPathList >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(SessionPath ) const>(_a, &__Login1User::DisplayChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(uint ) const>(_a, &__Login1User::GIDChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(bool ) const>(_a, &__Login1User::IdleHintChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(qulonglong ) const>(_a, &__Login1User::IdleSinceHintChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(qulonglong ) const>(_a, &__Login1User::IdleSinceHintMonotonicChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(bool ) const>(_a, &__Login1User::LingerChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(const QString & ) const>(_a, &__Login1User::NameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(const QString & ) const>(_a, &__Login1User::RuntimePathChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(const QString & ) const>(_a, &__Login1User::ServiceChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(SessionPathList ) const>(_a, &__Login1User::SessionsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(const QString & ) const>(_a, &__Login1User::SliceChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(const QString & ) const>(_a, &__Login1User::StateChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(qulonglong ) const>(_a, &__Login1User::TimestampChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(qulonglong ) const>(_a, &__Login1User::TimestampMonotonicChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1User::*)(uint ) const>(_a, &__Login1User::UIDChanged, 14))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SessionPath >(); break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SessionPathList >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<SessionPath*>(_v) = _t->display(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->gID(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->idleHint(); break;
        case 3: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHint(); break;
        case 4: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHintMonotonic(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->linger(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->runtimePath(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->service(); break;
        case 9: *reinterpret_cast<SessionPathList*>(_v) = _t->sessions(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->slice(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->state(); break;
        case 12: *reinterpret_cast<qulonglong*>(_v) = _t->timestamp(); break;
        case 13: *reinterpret_cast<qulonglong*>(_v) = _t->timestampMonotonic(); break;
        case 14: *reinterpret_cast<uint*>(_v) = _t->uID(); break;
        default: break;
        }
    }
}

const QMetaObject *__Login1User::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Login1User::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12__Login1UserE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Login1User::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void __Login1User::DisplayChanged(SessionPath _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __Login1User::GIDChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __Login1User::IdleHintChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __Login1User::IdleSinceHintChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __Login1User::IdleSinceHintMonotonicChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __Login1User::LingerChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __Login1User::NameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __Login1User::RuntimePathChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __Login1User::ServiceChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __Login1User::SessionsChanged(SessionPathList _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __Login1User::SliceChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __Login1User::StateChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __Login1User::TimestampChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __Login1User::TimestampMonotonicChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __Login1User::UIDChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1User *>(this), &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
