/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_Bluetooth1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_deepin_dde_Bluetooth1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_Bluetooth1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11__BluetoothE_t {};
} // unnamed namespace

template <> constexpr inline auto __Bluetooth::qt_create_metaobjectdata<qt_meta_tag_ZN11__BluetoothE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Bluetooth",
        "AdapterAdded",
        "",
        "adapterJSON",
        "AdapterPropertiesChanged",
        "AdapterRemoved",
        "DeviceAdded",
        "devJSON",
        "DevicePropertiesChanged",
        "DeviceRemoved",
        "CanSendFileChanged",
        "value",
        "StateChanged",
        "ClearUnpairedDevice",
        "QDBusPendingReply<>",
        "ClearUnpairedDeviceQueued",
        "ConnectDevice",
        "QDBusObjectPath",
        "devPath",
        "adapterPath",
        "ConnectDeviceQueued",
        "DebugInfo",
        "QDBusPendingReply<QString>",
        "DisconnectAudioDevices",
        "DisconnectAudioDevicesQueued",
        "DisconnectDevice",
        "DisconnectDeviceQueued",
        "GetAdapters",
        "GetDevices",
        "RegisterAgent",
        "agentPath",
        "RegisterAgentQueued",
        "RemoveDevice",
        "RemoveDeviceQueued",
        "RequestDiscovery",
        "RequestDiscoveryQueued",
        "SetAdapterAlias",
        "alias",
        "SetAdapterAliasQueued",
        "SetAdapterDiscoverable",
        "discoverable",
        "SetAdapterDiscoverableQueued",
        "SetAdapterDiscoverableTimeout",
        "discoverableTimeout",
        "SetAdapterDiscoverableTimeoutQueued",
        "SetAdapterDiscovering",
        "discovering",
        "SetAdapterDiscoveringQueued",
        "SetAdapterPowered",
        "powered",
        "SetAdapterPoweredQueued",
        "SetDeviceAlias",
        "device",
        "SetDeviceAliasQueued",
        "SetDeviceTrusted",
        "trusted",
        "SetDeviceTrustedQueued",
        "UnregisterAgent",
        "UnregisterAgentQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "CanSendFile",
        "State"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AdapterAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AdapterPropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AdapterRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'DeviceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DevicePropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DeviceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'CanSendFileChanged'
        QtMocHelpers::SignalData<void(bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(uint) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'ClearUnpairedDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'ClearUnpairedDeviceQueued'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ConnectDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QDBusObjectPath &)>(16, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 19 },
        }}),
        // Slot 'ConnectDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 19 },
        }}),
        // Slot 'DebugInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'DisconnectAudioDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(23, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'DisconnectAudioDevicesQueued'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DisconnectDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(25, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'DisconnectDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetAdapters'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(27, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'GetDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QDBusObjectPath &)>(28, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 17, 19 },
        }}),
        // Slot 'RegisterAgent'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(29, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 30 },
        }}),
        // Slot 'RegisterAgentQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 30 },
        }}),
        // Slot 'RemoveDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QDBusObjectPath &)>(32, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'RemoveDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'RequestDiscovery'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(34, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 },
        }}),
        // Slot 'RequestDiscoveryQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 },
        }}),
        // Slot 'SetAdapterAlias'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'SetAdapterAliasQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'SetAdapterDiscoverable'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(39, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'SetAdapterDiscoverableQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'SetAdapterDiscoverableTimeout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, uint)>(42, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 }, { QMetaType::UInt, 43 },
        }}),
        // Slot 'SetAdapterDiscoverableTimeoutQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, uint)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 }, { QMetaType::UInt, 43 },
        }}),
        // Slot 'SetAdapterDiscovering'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(45, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 }, { QMetaType::Bool, 46 },
        }}),
        // Slot 'SetAdapterDiscoveringQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 }, { QMetaType::Bool, 46 },
        }}),
        // Slot 'SetAdapterPowered'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(48, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 19 }, { QMetaType::Bool, 49 },
        }}),
        // Slot 'SetAdapterPoweredQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 19 }, { QMetaType::Bool, 49 },
        }}),
        // Slot 'SetDeviceAlias'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 52 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'SetDeviceAliasQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 52 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'SetDeviceTrusted'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(54, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 52 }, { QMetaType::Bool, 55 },
        }}),
        // Slot 'SetDeviceTrustedQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 52 }, { QMetaType::Bool, 55 },
        }}),
        // Slot 'UnregisterAgent'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(57, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 17, 30 },
        }}),
        // Slot 'UnregisterAgentQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 30 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 60 }, { 0x80000000 | 61, 62 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 67 }, { 0x80000000 | 68, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanSendFile'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'State'
        QtMocHelpers::PropertyData<uint>(70, QMetaType::UInt, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Bluetooth, qt_meta_tag_ZN11__BluetoothE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Bluetooth::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11__BluetoothE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11__BluetoothE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11__BluetoothE_t>.metaTypes,
    nullptr
} };

void __Bluetooth::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Bluetooth *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AdapterAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->AdapterPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->AdapterRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->DeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->DevicePropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->DeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->CanSendFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: { QDBusPendingReply<> _r = _t->ClearUnpairedDevice();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->ClearUnpairedDeviceQueued(); break;
        case 10: { QDBusPendingReply<> _r = _t->ConnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->ConnectDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 12: { QDBusPendingReply<QString> _r = _t->DebugInfo();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->DisconnectAudioDevices();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->DisconnectAudioDevicesQueued(); break;
        case 15: { QDBusPendingReply<> _r = _t->DisconnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->DisconnectDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 17: { QDBusPendingReply<QString> _r = _t->GetAdapters();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QString> _r = _t->GetDevices((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->RegisterAgent((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->RegisterAgentQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 21: { QDBusPendingReply<> _r = _t->RemoveDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->RemoveDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 23: { QDBusPendingReply<> _r = _t->RequestDiscovery((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->RequestDiscoveryQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 25: { QDBusPendingReply<> _r = _t->SetAdapterAlias((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->SetAdapterAliasQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: { QDBusPendingReply<> _r = _t->SetAdapterDiscoverable((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->SetAdapterDiscoverableQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 29: { QDBusPendingReply<> _r = _t->SetAdapterDiscoverableTimeout((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->SetAdapterDiscoverableTimeoutQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 31: { QDBusPendingReply<> _r = _t->SetAdapterDiscovering((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->SetAdapterDiscoveringQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: { QDBusPendingReply<> _r = _t->SetAdapterPowered((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->SetAdapterPoweredQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 35: { QDBusPendingReply<> _r = _t->SetDeviceAlias((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->SetDeviceAliasQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 37: { QDBusPendingReply<> _r = _t->SetDeviceTrusted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->SetDeviceTrustedQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 39: { QDBusPendingReply<> _r = _t->UnregisterAgent((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->UnregisterAgentQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 41: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 42: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 43: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(const QString & )>(_a, &__Bluetooth::AdapterAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(const QString & )>(_a, &__Bluetooth::AdapterPropertiesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(const QString & )>(_a, &__Bluetooth::AdapterRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(const QString & )>(_a, &__Bluetooth::DeviceAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(const QString & )>(_a, &__Bluetooth::DevicePropertiesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(const QString & )>(_a, &__Bluetooth::DeviceRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(bool ) const>(_a, &__Bluetooth::CanSendFileChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Bluetooth::*)(uint ) const>(_a, &__Bluetooth::StateChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canSendFile(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->state(); break;
        default: break;
        }
    }
}

const QMetaObject *__Bluetooth::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Bluetooth::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11__BluetoothE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Bluetooth::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void __Bluetooth::AdapterAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __Bluetooth::AdapterPropertiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __Bluetooth::AdapterRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __Bluetooth::DeviceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __Bluetooth::DevicePropertiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __Bluetooth::DeviceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __Bluetooth::CanSendFileChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Bluetooth *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __Bluetooth::StateChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Bluetooth *>(this), &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
