// This file is autogenerated. Changes will be overwritten.
#include "EJONY7H6NU/moc_com_deepin_Wm.cpp"
#include "EJONY7H6NU/moc_org_deepin_dde_Audio1.cpp"
#include "EJONY7H6NU/moc_org_deepin_dde_Audio1_Sink.cpp"
#include "EJONY7H6NU/moc_org_deepin_dde_Bluetooth1.cpp"
#include "EJONY7H6NU/moc_org_deepin_dde_Daemon1.cpp"
#include "EJONY7H6NU/moc_org_freedesktop_DBus.cpp"
#include "EJONY7H6NU/moc_org_freedesktop_login1_Manager.cpp"
#include "EJONY7H6NU/moc_org_freedesktop_login1_Session.cpp"
#include "EJONY7H6NU/moc_org_freedesktop_login1_User.cpp"
#include "EJONY7H6NU/moc_org_freedesktop_systemd1_Job.cpp"
#include "EJONY7H6NU/moc_org_freedesktop_systemd1_Manager.cpp"
#include "7OA5V33GOM/moc_inhibitor.cpp"
#include "TRQJ47NPDL/moc_iowaitwatcher.cpp"
#include "7OA5V33GOM/moc_session.cpp"
#include "7OA5V33GOM/moc_sessionmanager.cpp"
#include "7OA5V33GOM/moc_wmswitcher.cpp"
#include "7KRDZL6R5E/moc_fifo.cpp"
