/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Login1User -p /build/deepin-session/src/dde-session/dbusinterface/org_freedesktop_login1_User /build/deepin-session/src/dde-session/dbus/interface/org.freedesktop.login1.User.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_FREEDESKTOP_LOGIN1_USER_H
#define ORG_FREEDESKTOP_LOGIN1_USER_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>

#include "types/sessionpath.h"
#include "types/sessionpathlist.h"

/*
 * Proxy class for interface org.freedesktop.login1.User
 */
class __Login1UserPrivate;
class __Login1User : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.login1.User"; }

public:
    explicit __Login1User(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Login1User();

    Q_PROPERTY(SessionPath Display READ display NOTIFY DisplayChanged)
    SessionPath display();

    Q_PROPERTY(uint GID READ gID NOTIFY GIDChanged)
    uint gID();

    Q_PROPERTY(bool IdleHint READ idleHint NOTIFY IdleHintChanged)
    bool idleHint();

    Q_PROPERTY(qulonglong IdleSinceHint READ idleSinceHint NOTIFY IdleSinceHintChanged)
    qulonglong idleSinceHint();

    Q_PROPERTY(qulonglong IdleSinceHintMonotonic READ idleSinceHintMonotonic NOTIFY IdleSinceHintMonotonicChanged)
    qulonglong idleSinceHintMonotonic();

    Q_PROPERTY(bool Linger READ linger NOTIFY LingerChanged)
    bool linger();

    Q_PROPERTY(QString Name READ name NOTIFY NameChanged)
    QString name();

    Q_PROPERTY(QString RuntimePath READ runtimePath NOTIFY RuntimePathChanged)
    QString runtimePath();

    Q_PROPERTY(QString Service READ service NOTIFY ServiceChanged)
    QString service();

    Q_PROPERTY(SessionPathList Sessions READ sessions NOTIFY SessionsChanged)
    SessionPathList sessions();

    Q_PROPERTY(QString Slice READ slice NOTIFY SliceChanged)
    QString slice();

    Q_PROPERTY(QString State READ state NOTIFY StateChanged)
    QString state();

    Q_PROPERTY(qulonglong Timestamp READ timestamp NOTIFY TimestampChanged)
    qulonglong timestamp();

    Q_PROPERTY(qulonglong TimestampMonotonic READ timestampMonotonic NOTIFY TimestampMonotonicChanged)
    qulonglong timestampMonotonic();

    Q_PROPERTY(uint UID READ uID NOTIFY UIDChanged)
    uint uID();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Kill(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("Kill"), argumentList);
    }

    inline void KillQueued(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("Kill"), argumentList);
    }


    inline QDBusPendingReply<> Terminate()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Terminate"), argumentList);
    }

    inline void TerminateQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Terminate"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals
    void DisplayChanged(SessionPath  value) const;
    void GIDChanged(uint  value) const;
    void IdleHintChanged(bool  value) const;
    void IdleSinceHintChanged(qulonglong  value) const;
    void IdleSinceHintMonotonicChanged(qulonglong  value) const;
    void LingerChanged(bool  value) const;
    void NameChanged(const QString & value) const;
    void RuntimePathChanged(const QString & value) const;
    void ServiceChanged(const QString & value) const;
    void SessionsChanged(SessionPathList  value) const;
    void SliceChanged(const QString & value) const;
    void StateChanged(const QString & value) const;
    void TimestampChanged(qulonglong  value) const;
    void TimestampMonotonicChanged(qulonglong  value) const;
    void UIDChanged(uint  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __Login1UserPrivate *d_ptr;
};

namespace org {
  namespace freedesktop {
    namespace login1 {
      typedef ::__Login1User User;
    }
  }
}
#endif
