/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_Audio1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_deepin_dde_Audio1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_Audio1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8__Audio1E_t {};
} // unnamed namespace

template <> constexpr inline auto __Audio1::qt_create_metaobjectdata<qt_meta_tag_ZN8__Audio1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Audio1",
        "PortEnabledChanged",
        "",
        "in0",
        "in1",
        "in2",
        "BluetoothAudioModeChanged",
        "value",
        "BluetoothAudioModeOptsChanged",
        "CardsChanged",
        "CardsWithoutUnavailableChanged",
        "DefaultSinkChanged",
        "QDBusObjectPath",
        "DefaultSourceChanged",
        "IncreaseVolumeChanged",
        "MaxUIVolumeChanged",
        "ReduceNoiseChanged",
        "SinkInputsChanged",
        "QList<QDBusObjectPath>",
        "SinksChanged",
        "SourcesChanged",
        "IsPortEnabled",
        "QDBusPendingReply<bool>",
        "Reset",
        "QDBusPendingReply<>",
        "ResetQueued",
        "SetBluetoothAudioMode",
        "SetBluetoothAudioModeQueued",
        "SetDefaultSink",
        "SetDefaultSinkQueued",
        "SetDefaultSource",
        "SetDefaultSourceQueued",
        "SetPort",
        "SetPortQueued",
        "SetPortEnabled",
        "SetPortEnabledQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "BluetoothAudioMode",
        "BluetoothAudioModeOpts",
        "Cards",
        "CardsWithoutUnavailable",
        "DefaultSink",
        "DefaultSource",
        "IncreaseVolume",
        "MaxUIVolume",
        "ReduceNoise",
        "SinkInputs",
        "Sinks",
        "Sources"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PortEnabledChanged'
        QtMocHelpers::SignalData<void(uint, const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'BluetoothAudioModeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'BluetoothAudioModeOptsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'CardsChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'CardsWithoutUnavailableChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DefaultSinkChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 7 },
        }}),
        // Signal 'DefaultSourceChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 7 },
        }}),
        // Signal 'IncreaseVolumeChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'MaxUIVolumeChanged'
        QtMocHelpers::SignalData<void(double) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'ReduceNoiseChanged'
        QtMocHelpers::SignalData<void(bool) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'SinkInputsChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 7 },
        }}),
        // Signal 'SinksChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 7 },
        }}),
        // Signal 'SourcesChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 7 },
        }}),
        // Slot 'IsPortEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(uint, const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'ResetQueued'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetBluetoothAudioMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetBluetoothAudioModeQueued'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetDefaultSink'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetDefaultSinkQueued'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetDefaultSource'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(30, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetDefaultSourceQueued'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetPort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, const QString &, int)>(32, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'SetPortQueued'
        QtMocHelpers::SlotData<void(uint, const QString &, int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'SetPortEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, const QString &, bool)>(34, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'SetPortEnabledQueued'
        QtMocHelpers::SlotData<void(uint, const QString &, bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { 0x80000000 | 45, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'BluetoothAudioMode'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'BluetoothAudioModeOpts'
        QtMocHelpers::PropertyData<QStringList>(47, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
        // property 'Cards'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'CardsWithoutUnavailable'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'DefaultSink'
        QtMocHelpers::PropertyData<QDBusObjectPath>(50, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'DefaultSource'
        QtMocHelpers::PropertyData<QDBusObjectPath>(51, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'IncreaseVolume'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'MaxUIVolume'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags, 8),
        // property 'ReduceNoise'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'SinkInputs'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(55, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'Sinks'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(56, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'Sources'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(57, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Audio1, qt_meta_tag_ZN8__Audio1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Audio1::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8__Audio1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8__Audio1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8__Audio1E_t>.metaTypes,
    nullptr
} };

void __Audio1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Audio1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PortEnabledChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->BluetoothAudioModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->BluetoothAudioModeOptsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->CardsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->CardsWithoutUnavailableChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->DefaultSinkChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 6: _t->DefaultSourceChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 7: _t->IncreaseVolumeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->MaxUIVolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: _t->ReduceNoiseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->SinkInputsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 11: _t->SinksChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 12: _t->SourcesChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 13: { QDBusPendingReply<bool> _r = _t->IsPortEnabled((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->ResetQueued(); break;
        case 16: { QDBusPendingReply<> _r = _t->SetBluetoothAudioMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->SetBluetoothAudioModeQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: { QDBusPendingReply<> _r = _t->SetDefaultSink((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->SetDefaultSinkQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: { QDBusPendingReply<> _r = _t->SetDefaultSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->SetDefaultSourceQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: { QDBusPendingReply<> _r = _t->SetPort((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->SetPortQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 24: { QDBusPendingReply<> _r = _t->SetPortEnabled((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->SetPortEnabledQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 26: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 27: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 28: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(uint , const QString & , bool )>(_a, &__Audio1::PortEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QString & ) const>(_a, &__Audio1::BluetoothAudioModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QStringList & ) const>(_a, &__Audio1::BluetoothAudioModeOptsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QString & ) const>(_a, &__Audio1::CardsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QString & ) const>(_a, &__Audio1::CardsWithoutUnavailableChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QDBusObjectPath & ) const>(_a, &__Audio1::DefaultSinkChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QDBusObjectPath & ) const>(_a, &__Audio1::DefaultSourceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(bool ) const>(_a, &__Audio1::IncreaseVolumeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(double ) const>(_a, &__Audio1::MaxUIVolumeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(bool ) const>(_a, &__Audio1::ReduceNoiseChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QList<QDBusObjectPath> & ) const>(_a, &__Audio1::SinkInputsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QList<QDBusObjectPath> & ) const>(_a, &__Audio1::SinksChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Audio1::*)(const QList<QDBusObjectPath> & ) const>(_a, &__Audio1::SourcesChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        case 11:
        case 10:
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->bluetoothAudioMode(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->bluetoothAudioModeOpts(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->cards(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->cardsWithoutUnavailable(); break;
        case 4: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->defaultSink(); break;
        case 5: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->defaultSource(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->increaseVolume(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->maxUIVolume(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->reduceNoise(); break;
        case 9: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sinkInputs(); break;
        case 10: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sinks(); break;
        case 11: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sources(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setIncreaseVolume(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setReduceNoise(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__Audio1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Audio1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8__Audio1E_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Audio1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void __Audio1::PortEnabledChanged(uint _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void __Audio1::BluetoothAudioModeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __Audio1::BluetoothAudioModeOptsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __Audio1::CardsChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __Audio1::CardsWithoutUnavailableChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __Audio1::DefaultSinkChanged(const QDBusObjectPath & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __Audio1::DefaultSourceChanged(const QDBusObjectPath & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __Audio1::IncreaseVolumeChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __Audio1::MaxUIVolumeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __Audio1::ReduceNoiseChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __Audio1::SinkInputsChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __Audio1::SinksChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __Audio1::SourcesChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Audio1 *>(this), &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
