/****************************************************************************
** Meta object code from reading C++ file 'org_freedesktop_login1_Session.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dbusinterface/org_freedesktop_login1_Session.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_freedesktop_login1_Session.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15__Login1SessionE_t {};
} // unnamed namespace

template <> constexpr inline auto __Login1Session::qt_create_metaobjectdata<qt_meta_tag_ZN15__Login1SessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Login1Session",
        "PauseDevice",
        "",
        "in0",
        "in1",
        "in2",
        "ResumeDevice",
        "QDBusUnixFileDescriptor",
        "ActiveChanged",
        "value",
        "AuditChanged",
        "DesktopChanged",
        "DisplayChanged",
        "IdChanged",
        "IdleHintChanged",
        "IdleSinceHintChanged",
        "IdleSinceHintMonotonicChanged",
        "LeaderChanged",
        "LockedHintChanged",
        "NameChanged",
        "RemoteChanged",
        "RemoteHostChanged",
        "RemoteUserChanged",
        "ScopeChanged",
        "ServiceChanged",
        "StateChanged",
        "TTYChanged",
        "TimestampChanged",
        "TimestampMonotonicChanged",
        "TypeChanged",
        "VTNrChanged",
        "Activate",
        "QDBusPendingReply<>",
        "ActivateQueued",
        "Kill",
        "KillQueued",
        "Lock",
        "LockQueued",
        "PauseDeviceComplete",
        "PauseDeviceCompleteQueued",
        "ReleaseControl",
        "ReleaseControlQueued",
        "ReleaseDevice",
        "ReleaseDeviceQueued",
        "SetIdleHint",
        "SetIdleHintQueued",
        "SetLockedHint",
        "SetLockedHintQueued",
        "TakeControl",
        "TakeControlQueued",
        "TakeDevice",
        "QDBusPendingReply<QDBusUnixFileDescriptor,bool>",
        "QDBusReply<QDBusUnixFileDescriptor>",
        "bool&",
        "out1",
        "Terminate",
        "TerminateQueued",
        "Unlock",
        "UnlockQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Active",
        "Audit",
        "Desktop",
        "Display",
        "Id",
        "IdleHint",
        "IdleSinceHint",
        "IdleSinceHintMonotonic",
        "Leader",
        "LockedHint",
        "Name",
        "Remote",
        "RemoteHost",
        "RemoteUser",
        "Scope",
        "Service",
        "State",
        "TTY",
        "Timestamp",
        "TimestampMonotonic",
        "Type",
        "VTNr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PauseDevice'
        QtMocHelpers::SignalData<void(uint, uint, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'ResumeDevice'
        QtMocHelpers::SignalData<void(uint, uint, const QDBusUnixFileDescriptor &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 }, { 0x80000000 | 7, 5 },
        }}),
        // Signal 'ActiveChanged'
        QtMocHelpers::SignalData<void(bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'AuditChanged'
        QtMocHelpers::SignalData<void(uint) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 },
        }}),
        // Signal 'DesktopChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'DisplayChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'IdChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'IdleHintChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'IdleSinceHintChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 9 },
        }}),
        // Signal 'IdleSinceHintMonotonicChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 9 },
        }}),
        // Signal 'LeaderChanged'
        QtMocHelpers::SignalData<void(uint) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 },
        }}),
        // Signal 'LockedHintChanged'
        QtMocHelpers::SignalData<void(bool) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'RemoteChanged'
        QtMocHelpers::SignalData<void(bool) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'RemoteHostChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'RemoteUserChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'ScopeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'ServiceChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'TTYChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'TimestampChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 9 },
        }}),
        // Signal 'TimestampMonotonicChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 9 },
        }}),
        // Signal 'TypeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'VTNrChanged'
        QtMocHelpers::SignalData<void(uint) const>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 },
        }}),
        // Slot 'Activate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(31, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'ActivateQueued'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Kill'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, int)>(34, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'KillQueued'
        QtMocHelpers::SlotData<void(const QString &, int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'Lock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(36, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'LockQueued'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PauseDeviceComplete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, uint)>(38, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'PauseDeviceCompleteQueued'
        QtMocHelpers::SlotData<void(uint, uint)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'ReleaseControl'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(40, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'ReleaseControlQueued'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ReleaseDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, uint)>(42, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'ReleaseDeviceQueued'
        QtMocHelpers::SlotData<void(uint, uint)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'SetIdleHint'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(44, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'SetIdleHintQueued'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'SetLockedHint'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(46, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'SetLockedHintQueued'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'TakeControl'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(48, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'TakeControlQueued'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'TakeDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor,bool>(uint, uint)>(50, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'TakeDevice'
        QtMocHelpers::SlotData<QDBusReply<QDBusUnixFileDescriptor>(uint, uint, bool &)>(50, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 }, { 0x80000000 | 53, 54 },
        }}),
        // Slot 'Terminate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(55, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'TerminateQueued'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Unlock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(57, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'UnlockQueued'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 60 }, { 0x80000000 | 61, 62 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 67 }, { 0x80000000 | 68, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Active'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'Audit'
        QtMocHelpers::PropertyData<uint>(70, QMetaType::UInt, QMC::DefaultPropertyFlags, 3),
        // property 'Desktop'
        QtMocHelpers::PropertyData<QString>(71, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'Display'
        QtMocHelpers::PropertyData<QString>(72, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'Id'
        QtMocHelpers::PropertyData<QString>(73, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'IdleHint'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'IdleSinceHint'
        QtMocHelpers::PropertyData<qulonglong>(75, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 8),
        // property 'IdleSinceHintMonotonic'
        QtMocHelpers::PropertyData<qulonglong>(76, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 9),
        // property 'Leader'
        QtMocHelpers::PropertyData<uint>(77, QMetaType::UInt, QMC::DefaultPropertyFlags, 10),
        // property 'LockedHint'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(79, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'Remote'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'RemoteHost'
        QtMocHelpers::PropertyData<QString>(81, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'RemoteUser'
        QtMocHelpers::PropertyData<QString>(82, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
        // property 'Scope'
        QtMocHelpers::PropertyData<QString>(83, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'Service'
        QtMocHelpers::PropertyData<QString>(84, QMetaType::QString, QMC::DefaultPropertyFlags, 17),
        // property 'State'
        QtMocHelpers::PropertyData<QString>(85, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'TTY'
        QtMocHelpers::PropertyData<QString>(86, QMetaType::QString, QMC::DefaultPropertyFlags, 19),
        // property 'Timestamp'
        QtMocHelpers::PropertyData<qulonglong>(87, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 20),
        // property 'TimestampMonotonic'
        QtMocHelpers::PropertyData<qulonglong>(88, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 21),
        // property 'Type'
        QtMocHelpers::PropertyData<QString>(89, QMetaType::QString, QMC::DefaultPropertyFlags, 22),
        // property 'VTNr'
        QtMocHelpers::PropertyData<uint>(90, QMetaType::UInt, QMC::DefaultPropertyFlags, 23),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Login1Session, qt_meta_tag_ZN15__Login1SessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Login1Session::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15__Login1SessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15__Login1SessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15__Login1SessionE_t>.metaTypes,
    nullptr
} };

void __Login1Session::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Login1Session *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PauseDevice((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->ResumeDevice((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusUnixFileDescriptor>>(_a[3]))); break;
        case 2: _t->ActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->AuditChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->DesktopChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->DisplayChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->IdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->IdleHintChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->IdleSinceHintChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 9: _t->IdleSinceHintMonotonicChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 10: _t->LeaderChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 11: _t->LockedHintChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->RemoteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->RemoteHostChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->RemoteUserChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->ScopeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->ServiceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->TTYChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->TimestampChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 21: _t->TimestampMonotonicChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 22: _t->TypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->VTNrChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 24: { QDBusPendingReply<> _r = _t->Activate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->ActivateQueued(); break;
        case 26: { QDBusPendingReply<> _r = _t->Kill((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->KillQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: { QDBusPendingReply<> _r = _t->Lock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->LockQueued(); break;
        case 30: { QDBusPendingReply<> _r = _t->PauseDeviceComplete((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->PauseDeviceCompleteQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 32: { QDBusPendingReply<> _r = _t->ReleaseControl();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->ReleaseControlQueued(); break;
        case 34: { QDBusPendingReply<> _r = _t->ReleaseDevice((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->ReleaseDeviceQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 36: { QDBusPendingReply<> _r = _t->SetIdleHint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->SetIdleHintQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: { QDBusPendingReply<> _r = _t->SetLockedHint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->SetLockedHintQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: { QDBusPendingReply<> _r = _t->TakeControl((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->TakeControlQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: { QDBusPendingReply<QDBusUnixFileDescriptor,bool> _r = _t->TakeDevice((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor,bool>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusReply<QDBusUnixFileDescriptor> _r = _t->TakeDevice((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<> _r = _t->Terminate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->TerminateQueued(); break;
        case 46: { QDBusPendingReply<> _r = _t->Unlock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->UnlockQueued(); break;
        case 48: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 49: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 50: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusUnixFileDescriptor >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(uint , uint , const QString & )>(_a, &__Login1Session::PauseDevice, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(uint , uint , const QDBusUnixFileDescriptor & )>(_a, &__Login1Session::ResumeDevice, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(bool ) const>(_a, &__Login1Session::ActiveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(uint ) const>(_a, &__Login1Session::AuditChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::DesktopChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::DisplayChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::IdChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(bool ) const>(_a, &__Login1Session::IdleHintChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(qulonglong ) const>(_a, &__Login1Session::IdleSinceHintChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(qulonglong ) const>(_a, &__Login1Session::IdleSinceHintMonotonicChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(uint ) const>(_a, &__Login1Session::LeaderChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(bool ) const>(_a, &__Login1Session::LockedHintChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::NameChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(bool ) const>(_a, &__Login1Session::RemoteChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::RemoteHostChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::RemoteUserChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::ScopeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::ServiceChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::StateChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::TTYChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(qulonglong ) const>(_a, &__Login1Session::TimestampChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(qulonglong ) const>(_a, &__Login1Session::TimestampMonotonicChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(const QString & ) const>(_a, &__Login1Session::TypeChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Login1Session::*)(uint ) const>(_a, &__Login1Session::VTNrChanged, 23))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->audit(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->desktop(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->display(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->idleHint(); break;
        case 6: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHint(); break;
        case 7: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHintMonotonic(); break;
        case 8: *reinterpret_cast<uint*>(_v) = _t->leader(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->lockedHint(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->remote(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->remoteHost(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->remoteUser(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->scope(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->service(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->state(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->tTY(); break;
        case 18: *reinterpret_cast<qulonglong*>(_v) = _t->timestamp(); break;
        case 19: *reinterpret_cast<qulonglong*>(_v) = _t->timestampMonotonic(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 21: *reinterpret_cast<uint*>(_v) = _t->vTNr(); break;
        default: break;
        }
    }
}

const QMetaObject *__Login1Session::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Login1Session::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15__Login1SessionE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Login1Session::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void __Login1Session::PauseDevice(uint _t1, uint _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void __Login1Session::ResumeDevice(uint _t1, uint _t2, const QDBusUnixFileDescriptor & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void __Login1Session::ActiveChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __Login1Session::AuditChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __Login1Session::DesktopChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __Login1Session::DisplayChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __Login1Session::IdChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __Login1Session::IdleHintChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __Login1Session::IdleSinceHintChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __Login1Session::IdleSinceHintMonotonicChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __Login1Session::LeaderChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __Login1Session::LockedHintChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __Login1Session::NameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __Login1Session::RemoteChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __Login1Session::RemoteHostChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __Login1Session::RemoteUserChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __Login1Session::ScopeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __Login1Session::ServiceChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void __Login1Session::StateChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void __Login1Session::TTYChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void __Login1Session::TimestampChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void __Login1Session::TimestampMonotonicChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void __Login1Session::TypeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void __Login1Session::VTNrChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Login1Session *>(this), &staticMetaObject, 23, nullptr, _t1);
}
QT_WARNING_POP
