/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Login1Session -p /build/deepin-session/src/dde-session/dbusinterface/org_freedesktop_login1_Session /build/deepin-session/src/dde-session/dbus/interface/org.freedesktop.login1.Session.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_FREEDESKTOP_LOGIN1_SESSION_H
#define ORG_FREEDESKTOP_LOGIN1_SESSION_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.freedesktop.login1.Session
 */
class __Login1SessionPrivate;
class __Login1Session : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.login1.Session"; }

public:
    explicit __Login1Session(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Login1Session();

    Q_PROPERTY(bool Active READ active NOTIFY ActiveChanged)
    bool active();

    Q_PROPERTY(uint Audit READ audit NOTIFY AuditChanged)
    uint audit();

    Q_PROPERTY(QString Desktop READ desktop NOTIFY DesktopChanged)
    QString desktop();

    Q_PROPERTY(QString Display READ display NOTIFY DisplayChanged)
    QString display();

    Q_PROPERTY(QString Id READ id NOTIFY IdChanged)
    QString id();

    Q_PROPERTY(bool IdleHint READ idleHint NOTIFY IdleHintChanged)
    bool idleHint();

    Q_PROPERTY(qulonglong IdleSinceHint READ idleSinceHint NOTIFY IdleSinceHintChanged)
    qulonglong idleSinceHint();

    Q_PROPERTY(qulonglong IdleSinceHintMonotonic READ idleSinceHintMonotonic NOTIFY IdleSinceHintMonotonicChanged)
    qulonglong idleSinceHintMonotonic();

    Q_PROPERTY(uint Leader READ leader NOTIFY LeaderChanged)
    uint leader();

    Q_PROPERTY(bool LockedHint READ lockedHint NOTIFY LockedHintChanged)
    bool lockedHint();

    Q_PROPERTY(QString Name READ name NOTIFY NameChanged)
    QString name();

    Q_PROPERTY(bool Remote READ remote NOTIFY RemoteChanged)
    bool remote();

    Q_PROPERTY(QString RemoteHost READ remoteHost NOTIFY RemoteHostChanged)
    QString remoteHost();

    Q_PROPERTY(QString RemoteUser READ remoteUser NOTIFY RemoteUserChanged)
    QString remoteUser();

    Q_PROPERTY(QString Scope READ scope NOTIFY ScopeChanged)
    QString scope();

    Q_PROPERTY(QString Service READ service NOTIFY ServiceChanged)
    QString service();

    Q_PROPERTY(QString State READ state NOTIFY StateChanged)
    QString state();

    Q_PROPERTY(QString TTY READ tTY NOTIFY TTYChanged)
    QString tTY();

    Q_PROPERTY(qulonglong Timestamp READ timestamp NOTIFY TimestampChanged)
    qulonglong timestamp();

    Q_PROPERTY(qulonglong TimestampMonotonic READ timestampMonotonic NOTIFY TimestampMonotonicChanged)
    qulonglong timestampMonotonic();

    Q_PROPERTY(QString Type READ type NOTIFY TypeChanged)
    QString type();

    Q_PROPERTY(uint VTNr READ vTNr NOTIFY VTNrChanged)
    uint vTNr();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Activate()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Activate"), argumentList);
    }

    inline void ActivateQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Activate"), argumentList);
    }


    inline QDBusPendingReply<> Kill(const QString &in0, int in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("Kill"), argumentList);
    }

    inline void KillQueued(const QString &in0, int in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("Kill"), argumentList);
    }


    inline QDBusPendingReply<> Lock()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Lock"), argumentList);
    }

    inline void LockQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Lock"), argumentList);
    }


    inline QDBusPendingReply<> PauseDeviceComplete(uint in0, uint in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("PauseDeviceComplete"), argumentList);
    }

    inline void PauseDeviceCompleteQueued(uint in0, uint in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("PauseDeviceComplete"), argumentList);
    }


    inline QDBusPendingReply<> ReleaseControl()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ReleaseControl"), argumentList);
    }

    inline void ReleaseControlQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("ReleaseControl"), argumentList);
    }


    inline QDBusPendingReply<> ReleaseDevice(uint in0, uint in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ReleaseDevice"), argumentList);
    }

    inline void ReleaseDeviceQueued(uint in0, uint in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("ReleaseDevice"), argumentList);
    }


    inline QDBusPendingReply<> SetIdleHint(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetIdleHint"), argumentList);
    }

    inline void SetIdleHintQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetIdleHint"), argumentList);
    }


    inline QDBusPendingReply<> SetLockedHint(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetLockedHint"), argumentList);
    }

    inline void SetLockedHintQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetLockedHint"), argumentList);
    }


    inline QDBusPendingReply<> TakeControl(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("TakeControl"), argumentList);
    }

    inline void TakeControlQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("TakeControl"), argumentList);
    }


    inline QDBusPendingReply<QDBusUnixFileDescriptor, bool> TakeDevice(uint in0, uint in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("TakeDevice"), argumentList);
    }


    inline QDBusReply<QDBusUnixFileDescriptor> TakeDevice(uint in0, uint in1, bool &out1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("TakeDevice"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().count() == 2) {
            out1 = qdbus_cast<bool>(reply.arguments().at(1));
        }
        return reply;
    }

    inline QDBusPendingReply<> Terminate()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Terminate"), argumentList);
    }

    inline void TerminateQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Terminate"), argumentList);
    }


    inline QDBusPendingReply<> Unlock()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Unlock"), argumentList);
    }

    inline void UnlockQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Unlock"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void PauseDevice(uint in0, uint in1, const QString &in2);
    void ResumeDevice(uint in0, uint in1, const QDBusUnixFileDescriptor &in2);
    // begin property changed signals
    void ActiveChanged(bool  value) const;
    void AuditChanged(uint  value) const;
    void DesktopChanged(const QString & value) const;
    void DisplayChanged(const QString & value) const;
    void IdChanged(const QString & value) const;
    void IdleHintChanged(bool  value) const;
    void IdleSinceHintChanged(qulonglong  value) const;
    void IdleSinceHintMonotonicChanged(qulonglong  value) const;
    void LeaderChanged(uint  value) const;
    void LockedHintChanged(bool  value) const;
    void NameChanged(const QString & value) const;
    void RemoteChanged(bool  value) const;
    void RemoteHostChanged(const QString & value) const;
    void RemoteUserChanged(const QString & value) const;
    void ScopeChanged(const QString & value) const;
    void ServiceChanged(const QString & value) const;
    void StateChanged(const QString & value) const;
    void TTYChanged(const QString & value) const;
    void TimestampChanged(qulonglong  value) const;
    void TimestampMonotonicChanged(qulonglong  value) const;
    void TypeChanged(const QString & value) const;
    void VTNrChanged(uint  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __Login1SessionPrivate *d_ptr;
};

namespace org {
  namespace freedesktop {
    namespace login1 {
      typedef ::__Login1Session Session;
    }
  }
}
#endif
