// SPDX-FileCopyrightText: 2021 - 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef __XCURSOR_REMAP_H__
#define __XCURSOR_REMAP_H__

int xc_left_ptr_to_watch(int enabled);

#endif
