/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Session1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SESSION1ADAPTOR_H
#define SESSION1ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "impl/session.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.deepin.dde.Session1
 */
class Session1Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.deepin.dde.Session1")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.deepin.dde.Session1\">\n"
"    <method name=\"Logout\"/>\n"
"    <method name=\"GetSessionPid\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"pid\"/>\n"
"    </method>\n"
"    <method name=\"GetSessionPath\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"sessionpath\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Session1Adaptor(Session *parent);
    ~Session1Adaptor() override;

    inline Session *parent() const
    { return static_cast<Session *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString GetSessionPath();
    int GetSessionPid();
    void Logout();
Q_SIGNALS: // SIGNALS
};

#endif
