/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Sink -p /build/deepin-session/src/dde-session/dbusinterface/org_deepin_dde_Audio1_Sink /build/deepin-session/src/dde-session/dbus/interface/org.deepin.dde.Audio1.Sink.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_DEEPIN_DDE_AUDIO1_SINK_H
#define ORG_DEEPIN_DDE_AUDIO1_SINK_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.deepin.dde.Audio1.Sink
 */
class __SinkPrivate;
class __Sink : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Audio1.Sink"; }

public:
    explicit __Sink(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Sink();

    Q_PROPERTY(double Balance READ balance NOTIFY BalanceChanged)
    double balance();

    Q_PROPERTY(double BaseVolume READ baseVolume NOTIFY BaseVolumeChanged)
    double baseVolume();

    Q_PROPERTY(uint Card READ card NOTIFY CardChanged)
    uint card();

    Q_PROPERTY(QString Description READ description NOTIFY DescriptionChanged)
    QString description();

    Q_PROPERTY(double Fade READ fade NOTIFY FadeChanged)
    double fade();

    Q_PROPERTY(bool Mute READ mute NOTIFY MuteChanged)
    bool mute();

    Q_PROPERTY(QString Name READ name NOTIFY NameChanged)
    QString name();

    Q_PROPERTY(bool SupportBalance READ supportBalance NOTIFY SupportBalanceChanged)
    bool supportBalance();

    Q_PROPERTY(double Volume READ volume NOTIFY VolumeChanged)
    double volume();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusObjectPath> GetMeter()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetMeter"), argumentList);
    }



    inline QDBusPendingReply<> SetBalance(double in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetBalance"), argumentList);
    }

    inline void SetBalanceQueued(double in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetBalance"), argumentList);
    }


    inline QDBusPendingReply<> SetFade(double in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetFade"), argumentList);
    }

    inline void SetFadeQueued(double in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetFade"), argumentList);
    }


    inline QDBusPendingReply<> SetMute(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetMute"), argumentList);
    }

    inline void SetMuteQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetMute"), argumentList);
    }


    inline QDBusPendingReply<> SetPort(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetPort"), argumentList);
    }

    inline void SetPortQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetPort"), argumentList);
    }


    inline QDBusPendingReply<> SetVolume(double in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetVolume"), argumentList);
    }

    inline void SetVolumeQueued(double in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetVolume"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals
    void BalanceChanged(double  value) const;
    void BaseVolumeChanged(double  value) const;
    void CardChanged(uint  value) const;
    void DescriptionChanged(const QString & value) const;
    void FadeChanged(double  value) const;
    void MuteChanged(bool  value) const;
    void NameChanged(const QString & value) const;
    void SupportBalanceChanged(bool  value) const;
    void VolumeChanged(double  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __SinkPrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      namespace audio1 {
        typedef ::__Sink Sink;
      }
    }
  }
}
#endif
