/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c SessionDaemon -p /build/deepin-session/src/dde-session/dbusinterface/org_deepin_dde_Daemon1 /build/deepin-session/src/dde-session/dbus/interface/org.deepin.dde.Daemon1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_DEEPIN_DDE_DAEMON1_H
#define ORG_DEEPIN_DDE_DAEMON1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.deepin.dde.Daemon1
 */
class __SessionDaemonPrivate;
class __SessionDaemon : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Daemon1"; }

public:
    explicit __SessionDaemon(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__SessionDaemon();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> CallTrace(uint times, uint seconds)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(times) << QVariant::fromValue(seconds);
        return asyncCallWithArgumentList(QStringLiteral("CallTrace"), argumentList);
    }

    inline void CallTraceQueued(uint times, uint seconds)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(times) << QVariant::fromValue(seconds);

        CallQueued(QStringLiteral("CallTrace"), argumentList);
    }


    inline QDBusPendingReply<> StartPart2()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("StartPart2"), argumentList);
    }

    inline void StartPart2Queued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("StartPart2"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);

private:
    __SessionDaemonPrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__SessionDaemon Daemon1;
    }
  }
}
#endif
